@@ -26,6 +26,7 @@ static char SccsId[] = "%W%  %G%";
  */
 
 #include <stdio.h>	/* define stderr, NULL */
+#include <sys/types.h>	/* define stderr, NULL */
 #include <X11/Xlib.h>
 #include "buttons.h"
 
@@ -361,8 +362,8 @@ static int btn_Control ( buttonbox, event, response )
 	  mask[0] = select_mask[0];
 	  mask[1] = select_mask[1];
 
-	  if( select(select_size, mask,
-		     (int *)0, (int *)0, (struct timeval *)0) <0 )
+	  if( select(select_size, (fd_set *)mask,
+		     (fd_set *)0, (fd_set *)0, (struct timeval *)0) <0 )
 	    perror("select error");
 	  /* both masks have only one bit, look for match */
 	  if( (mask[0] & x_mask[0]) || (mask[1] & x_mask[1]) ) {
