@@ -10,13 +10,14 @@ static char SccsId[] = "%W%  %G%";
  * Subroutines:	static btn_Stencil()		returns: void
  * Subroutines:	static btn_StencilAlligned()	returns: void
  * Xlib calls:	none
- * Copyright:	1989 Smithsonian Astrophysical Observatory
+ * Copyright:	1989, 1995 Smithsonian Astrophysical Observatory
  *		You may do anything you like with this file except remove
  *		this copyright.  The Smithsonian Astrophysical Observatory
  *		makes no representations about the suitability of this
  *		software for any purpose.  It is provided "as is" without
  *		express or implied warranty.
  * Modified:	{0} Michael VanHilst	initial version		18 March 1989
+ *		{1} Doug Mink   cast before right shifting	   4 May 1995
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -251,7 +252,7 @@ static void btn_StencilInv ( src, msk, dst, last_dst, first_mask, last_mask,
       m++;
       mask |= (*m << lshift);
       mask &= (unsigned char)first_mask;
-      val = ((ff - *s) >> rshift);
+      val = ((unsigned char)(ff - *s) >> rshift);
       s++;
       val |= ((ff - *s) << lshift);
       *d = (*d & (ff - mask)) | (val & mask);
@@ -261,7 +262,7 @@ static void btn_StencilInv ( src, msk, dst, last_dst, first_mask, last_mask,
       mask = (*m >> rshift);
       m++;
       mask |= (*m << lshift);
-      val = ((ff - *s) >> rshift);
+      val = ((unsigned char)(ff - *s) >> rshift);
       s++;
       val |= ((ff - *s) << lshift);
       *d = (*d & (ff - mask)) | (val & mask);
@@ -269,13 +270,13 @@ static void btn_StencilInv ( src, msk, dst, last_dst, first_mask, last_mask,
     /* handle last (maybe partial) dst byte */
     if( last_mask < 0 ) {
       mask = (*m >> rshift) & (unsigned char)(-last_mask);
-      *d = (*d & (ff - mask)) | (((ff - *s) >> rshift) & mask);
+      *d = (*d & (ff - mask)) | (((unsigned char)(ff - *s) >> rshift) & mask);
     } else if( last_mask > 0 ) {
       mask = (*m >> rshift);
       m++;
       mask |= (*m << lshift);
       mask &= (unsigned char)last_mask;
-      val = ((ff - *s) >> rshift);
+      val = ((unsigned char)(ff - *s) >> rshift);
       s++;
       val |= ((ff - *s) << lshift);
       *d = (*d & (ff - mask)) | (val & mask);
