@@ -8,8 +8,9 @@ static char SccsId[] = "%W%  %G%";
  * Subroutine:	parse_scale()			returns: int
  * Subroutine:	parse_color()			returns: int
  * Subroutine:	parse_display()			returns: int
+ * Subroutine:	parse_cursor()			returns: int
  * Xlib calls:	none
- * Copyright:	1994 Smithsonian Astrophysical Observatory
+ * Copyright:	1994,1996 Smithsonian Astrophysical Observatory
  *		You may do anything you like with this file except remove
  *		this copyright.  The Smithsonian Astrophysical Observatory
  *		makes no representations about the suitability of this
@@ -20,6 +21,7 @@ static char SccsId[] = "%W%  %G%";
  *		{2} MVH	BSDonly strings.h compatability		  19 Feb 1990
  *		{3} Doug Mink           add -lfrac fraction       13 May 1994
  *		{4} Doug Mink           add -hi option            13 May 1994
+ *		{5} Doug Mink           add cursor options        25 Oct 1996
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -38,6 +40,7 @@ static char SccsId[] = "%W%  %G%";
 
 #include <X11/Xlib.h>		/* X window stuff */
 #include <X11/Xutil.h>		/* X window manager stuff */
+#include <stdlib.h>
 #include "hfiles/constant.h"	/* define codes */
 #include "hfiles/struct.h"	/* declare structure types */
 #include "hfiles/extern.h"	/* extern main ximage parameter structures */
@@ -235,6 +238,7 @@ int parse_scale ( argc, argv, argi, got_scale )
     /* file reading saturation level */
     if( ((++i) < argc) && (sscanf(argv[i], "%f", &val) == 1) ) {
       img.fimax = val;
+      img.fsmax = 1;
       *got_scale |= CMD_FREAD;
     } else
       return( usage("saturate", argc, argv, i-1, i) );
@@ -242,6 +246,7 @@ int parse_scale ( argc, argv, argi, got_scale )
     /* file reading threshold level */
     if( ((++i) < argc) && (sscanf(argv[i], "%f", &val) == 1) ) {
       img.fimin = val;
+      img.fsmin = 1;
       *got_scale |= CMD_FREAD;
     } else
       return( usage("threshold", argc, argv, i-1, i) );
@@ -334,3 +339,147 @@ int parse_display ( argc, argv, argi, got_geo, displayname )
   *got_geo |= CMD_GEOMETRY;
   return( 1 );
 }
+/*
+ * Subroutine:	parse_cursor
+ * Purpose:	Parse command line for cursor mode, type, size, position setting
+ * Returns:	1 if one of its parameters was found, else 0
+ */
+int parse_cursor ( argc, argv, argi )
+     int argc;		/* total number of arg tokens */
+     char *argv[];	/* array of arg tokens */
+     int *argi;		/* first arg to check, (returned as last arg used) */
+{
+  int i;
+  int usage();
+  char *temp, ctemp;
+  float ftemp;
+
+  i = *argi;
+  
+  if( strcmp(argv[i], "-cmode") == 0) {
+    control.mode = COP;
+    }
+
+  else if( strcmp(argv[i], "-pmode") == 0) {
+    control.mode = ZOP;
+    }
+
+  else if( strcmp(argv[i], "-cpie") == 0) {
+    control.mode = COP;
+    cursor.type = COP_PieSlice;
+    if ( ((i+1) < argc) && ((ftemp = atof(argv[i+1])) > 0) ) {
+      cursor.win.rayX = -ftemp;
+      cursor.win.rayY = -ftemp;
+      cursor.file.Xdim = -ftemp;
+      cursor.file.Ydim = -ftemp;
+      i++;
+      }
+    }
+
+  else if( strcmp(argv[i], "-ccir") == 0) {
+    control.mode = COP;
+    cursor.type = COP_Circle;
+    if ( ((i+1) < argc) && ((ftemp = atof(argv[i+1])) > 0) ) {
+      cursor.win.rayX = -ftemp;
+      cursor.win.rayY = -ftemp;
+      cursor.file.Xdim = -ftemp;
+      cursor.file.Ydim = -ftemp;
+      i++;
+      }
+    }
+
+  else if( strcmp(argv[i], "-cbox") == 0) {
+    control.mode = COP;
+    cursor.type = COP_Box;
+    if ( ((i+1) < argc) && ((ftemp = atof(argv[i+1])) > 0) ) {
+      cursor.win.rayX = -ftemp;
+      cursor.win.rayY = -ftemp;
+      cursor.file.Xdim = -ftemp;
+      cursor.file.Ydim = -ftemp;
+      i++;
+      }
+    if ( ((i+1) < argc) && ((ftemp = atof(argv[i+1])) > 0) ) {
+      cursor.win.rayY = -ftemp;
+      cursor.file.Ydim = -ftemp;
+      i++;
+      }
+    }
+
+  else if( strcmp(argv[i], "-cell") == 0) {
+    control.mode = COP;
+    cursor.type = COP_Ellipse;
+    if ( ((i+1) < argc) && ((ftemp = atof(argv[i+1])) > 0) ) {
+      cursor.win.rayX = -ftemp;
+      cursor.win.rayY = -ftemp;
+      cursor.file.Xdim = -ftemp;
+      cursor.file.Ydim = -ftemp;
+      i++;
+      }
+    if ( ((i+1) < argc) && ((ftemp = atof(argv[i+1])) > 0) ) {
+      cursor.win.rayY = -ftemp;
+      cursor.file.Ydim = -ftemp;
+      i++;
+      }
+    if ( ((i+1) < argc) && ((ftemp = atof(argv[i+1])) > 0) ) {
+      cursor.rot.angle = degrad(ftemp);
+      i++;
+      }
+    }
+
+  else if( strcmp(argv[i], "-ctype") == 0) {
+    control.mode = COP;
+    if ( (++i) < argc ) {
+      temp = argv[i];
+      ctemp = temp[0];
+      if (ctemp == 'a')
+	cursor.type = COP_Arrow;
+      else if (ctemp == 'b')
+	cursor.type = COP_Box;
+      else if (ctemp == 'c')
+	cursor.type = COP_Circle;
+      else if (ctemp == 'e')
+	cursor.type = COP_Ellipse;
+      else if (ctemp == 'p')
+	cursor.type = COP_Point;
+      else if (ctemp == 's')
+	cursor.type = COP_PieSlice;
+      else
+	return (0);
+      }
+    else
+      return (0);
+    }
+
+  else if( strcmp(argv[i], "-mode") == 0) {
+    if ( (++i) < argc ) {
+      temp = argv[i];
+      ctemp = temp[0];
+      if (ctemp == 'c')
+	control.mode = COP;	/* cursors */
+      else if (ctemp == 'e')
+	control.mode = EOP;	/* environment controls */
+      else if (ctemp == 'm')
+	control.mode = MOP;	/* color maps */
+      else if (ctemp == 'r')
+	control.mode = ROP;	/* region controls */
+      else if (ctemp == 's')
+	control.mode = SOP;	/* image reading and scaling */
+      else if (ctemp == 'p')
+	control.mode = ZOP;	/* pan and zoom */
+      else if (ctemp == 'v')
+	control.mode = VOP;	/* color manipulation */
+      else if (ctemp == 'z')
+	control.mode = ZOP;	/* pan and zoom */
+      else
+	return (0);
+      }
+    else
+      return (0);
+    }
+
+  else {
+    return( 0 );
+  }
+  *argi = i;
+  return( 1 );
+}
