@@ -13,7 +13,7 @@ static char SccsId[] = "%W%  %G%";
  * Subroutine:	write_disk()		returns: int
  * Subroutine:	close_disk()		returns: void
  * UNIX calls:	open(), fcntl(), lseek(), read(), write(), close()
- * Copyright:	1989 Smithsonian Astrophysical Observatory
+ * Copyright:	1999 Smithsonian Astrophysical Observatory
  *		You may do anything you like with this file except remove
  *		this copyright.  The Smithsonian Astrophysical Observatory
  *		makes no representations about the suitability of this
@@ -22,12 +22,15 @@ static char SccsId[] = "%W%  %G%";
  * Modified:	{0} Michael VanHilst	initial version		  6 Oct 1989
  *		{1} Jay Travisano (STScI)  VMS changes           10 Nov 1989
  *		{2} Doug Mink  blocking set to 0 in flush_disk   18 Oct 1995
+ *		{3} Doug Mink  use stdio for I/O declarations    13 Aug 1998
+ *		{4} Doug Mink  fix lseek dec. in VMS section     26 Feb 1999
  *		{n} <who> -- <does what> -- <when>
  */
 
 #ifndef VMS
 
 #include <stdio.h>		/* define stderr, FILE, NULL, etc */
+#include <unistd.h>		/* define read, write, lseek */
 #include <sys/file.h>		/* define open */
 #include <fcntl.h>		/* define fcntl */
 
@@ -35,7 +38,8 @@ static char SccsId[] = "%W%  %G%";
  * Subroutine:	open_disk
  * Returns:	File descriptor of open file (suitable for read())
  */
-int open_disk ( filename, write_flag, no_block )
+int
+open_disk ( filename, write_flag, no_block )
      char *filename;
      int write_flag;	/* i: 1=WriteOnly, 0=ReadWrite, -1=ReadOnly */
      int no_block;	/* i: flag to set non-blocking flag */
@@ -68,7 +72,8 @@ int open_disk ( filename, write_flag, no_block )
  * Subroutine:	fcntl_disk
  * Purpose:	Change an open file's flags, check for errors
  */
-void fcntl_disk ( fd, write_flag, no_block, filename )
+void
+fcntl_disk ( fd, write_flag, no_block, filename )
      int fd;		/* i: already open file descriptor */
      int write_flag;	/* i: 1=WriteOnly, 0=ReadWrite, -1=ReadOnly */
      int no_block;	/* i: include non-blocking flag */
@@ -99,7 +104,8 @@ void fcntl_disk ( fd, write_flag, no_block, filename )
  * Subroutine:	flush_disk
  * Purpose:	Read to functional end of file (useful with dynamic IO)
  */
-void flush_disk ( fd, filename )
+void
+flush_disk ( fd, filename )
      int fd;
      char *filename;
 {
@@ -152,12 +158,12 @@ void flush_disk ( fd, filename )
  * Subroutine:	lseek_disk
  * Purpose:	Skip into a disk file before reading, check for errors
  */
-int lseek_disk ( fd, nbytes, filename )
+int
+lseek_disk ( fd, nbytes, filename )
      int fd;
      int nbytes;
      char *filename;		/* [i]: name of file being accessed */
 {
-  long lseek();			/* type not declared in <sys/file.h> */
 
   if( lseek(fd, (long)nbytes, L_SET) < 0 ) {
     perror("lseek");
@@ -181,7 +187,8 @@ int lseek_disk ( fd, nbytes, filename )
  * Note:	BSD4.3 interrupts reads on any signal.  Thus reads may
  *		be broken into (hopefully consecutive) pieces.
  */
-int read_disk ( fd, buf, nbytes, report_error, filename, detail )
+int
+read_disk ( fd, buf, nbytes, report_error, filename, detail )
      int fd;
      char *buf;			/* i: buffer to receive read data */
      int nbytes;		/* i: number of bytes expected */
@@ -229,7 +236,8 @@ int read_disk ( fd, buf, nbytes, report_error, filename, detail )
  * Subroutine:	write_disk
  * Purpose:	Write data to the open disk file or stream
  */
-int write_disk ( fd, buf, nbytes, filename )
+int
+write_disk ( fd, buf, nbytes, filename )
      int fd;
      char *buf;
      int nbytes;
@@ -319,7 +327,8 @@ void close_disk ( fd, filename )
  * Subroutine:	open_disk
  * Returns:	File descriptor of open file (suitable for read())
  */
-int open_disk ( filename, write_flag, no_block )
+int
+open_disk ( filename, write_flag, no_block )
      char *filename;
      int write_flag;	/* i: 1=WriteOnly, 0=ReadWrite, -1=ReadOnly */
      int no_block;	/* i: flag to set non-blocking flag */
@@ -352,7 +361,8 @@ int open_disk ( filename, write_flag, no_block )
  * Subroutine:	fcntl_disk
  * Purpose:	Change an open file's flags, check for errors
  */
-void fcntl_disk ( fd, write_flag, no_block, filename )
+void
+fcntl_disk ( fd, write_flag, no_block, filename )
      int fd;			/* i: already open file descriptor */
      int write_flag;		/* i: 0=read, else write */
      int no_block;		/* i: include non-blocking flag */
@@ -365,7 +375,8 @@ void fcntl_disk ( fd, write_flag, no_block, filename )
  * Subroutine:	lseek_disk
  * Purpose:	Skip into a disk file before reading, check for errors
  */
-int lseek_disk ( fd, nbytes, filename )
+int
+lseek_disk ( fd, nbytes, filename )
      int fd;
      int nbytes;
      char *filename;		/* [i]: name of file being accessed */
@@ -392,7 +403,8 @@ int lseek_disk ( fd, nbytes, filename )
  * Note:	If report_error is 0, reading fewer than nbytes
  *		is not treated as an error.
  */
-int read_disk ( fd, buf, nbytes, report_error, filename, detail )
+int
+read_disk ( fd, buf, nbytes, report_error, filename, detail )
      int fd;
      char *buf;			/* i: buffer to receive read data */
      int nbytes;		/* i: number of bytes expected */
@@ -435,7 +447,8 @@ int read_disk ( fd, buf, nbytes, report_error, filename, detail )
  * Subroutine:	write_disk
  * Purpose:	Write data to the open disk file or stream
  */
-void write_disk ( fd, buf, nbytes, filename )
+void
+write_disk ( fd, buf, nbytes, filename )
      int fd;
      char *buf;
      int nbytes;
@@ -462,7 +475,8 @@ void write_disk ( fd, buf, nbytes, filename )
  * Subroutine:	close_disk
  * Purpose:	Close a disk file
  */
-void close_disk ( fd, filename )
+void
+close_disk ( fd, filename )
      int fd;
      char *filename;
 {
