@@ -5,7 +5,7 @@ static char SccsId[] = "%W%  %G%";
 /* Module:	disppsct.c (Display Postscript)
  * Purpose:	Dump contents of the display window to a postscript printer.
  * Subroutine:	screen_dump()			returns: void
- * Copyright:	1989 NOAO & Smithsonian Astrophysical Observatory
+ * Copyright:	1989,1998 NOAO & Smithsonian Astrophysical Observatory
  *		You may do anything you like with this file except remove
  *		this copyright.  The Smithsonian Astrophysical Observatory
  *		makes no representations about the suitability of this
@@ -16,6 +16,8 @@ static char SccsId[] = "%W%  %G%";
  *		{1} Jay Travisano (STScI)    VMS changes	10 Nov 1989
  *              {2} MVH BSDonly strings.h compatability		19 Feb 1990
  *              {3} Change R_DISPOSE printer from lw to lp	 1 May 1995
+ *              {4} Update VMS fixes (Harry Payne STScI)         1 Jun 1998
+ *              {5} Fix bug in VMS ifdef (Allan Brighton ESO)   20 Jul 1998
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -56,8 +58,13 @@ screen_dump ()
 }
 #else
 
+#ifdef VMS
+#define R_DISPOSE "print/delete %s"	/* printer dispose command */
+#define P_DISPOSE "print/delete/queue=%s %s"  /* dispose to user's printer */
+#else
 #define	R_DISPOSE "lpr -Plp -r %s"	/* printer dispose command	*/
 #define P_DISPOSE "lpr -P%s -r %s"	/* dispose to user's printer	*/
+#endif
 #define	SEGSIZE		16		/* output segment size (bytes)	*/
 #define	SEGBITS		(SEGSIZE*8)
 #define	BITFLIP		0		/* bit-flip each byte for P.S.?	*/
@@ -568,7 +575,9 @@ bitmap_to_postscript (fp, bitmap, width, height, depth, linebytes, zero, scale)
     (void)fprintf(fp, "(%s) show\n", img.filename);
   }
   (void)fprintf(fp, "%d %d moveto\n", width - 144, MARGIN/2);
+#ifndef VMS
   (void)fprintf(fp, "(%s) show\n", make_label());
+#endif
   (void)fprintf(fp, "showpage\n");
   (void)fprintf(fp, "%%%%EOF\n");
 }
