@@ -152,6 +152,10 @@ static char SccsConstId[] = "%W%  %G%";
 #define COP_Arrow	0x0600
 #define COP_Text	0x0700
 #define COP_Bitmap	0x0800
+#define COP_Square	0x0900
+#define COP_Diamond	0x0a00
+#define COP_Cross	0x0b00
+#define COP_Ex		0x0c00
 #define COP_Annuli	0x1000
 #define COP_PieSlice	0x2000
 #define COP_SetOrigin	0x4000
