@@ -6,6 +6,7 @@
  *
  *  updated with new names 21 September 1988, 30 January 1989
  *  updated with wcs 6 July 1995 by Doug Mink, SAO
+ *  dropped wcscom and wcscoor 17 July 1998 - Doug Mink, SAO
  *
  *  externs to reference structures declared in MainInit.c
  */
@@ -24,5 +25,3 @@ extern struct windowRec panbox;
 extern struct cursorRec cursor;
 extern struct bufferRec buffer;
 extern struct WorldCoor *wcs;
-extern char *wcscoor;        /* Output coordinate system */
-extern char *wcscommand;     /* WCS command */
