@@ -4,8 +4,6 @@ static char SccsRegionId[] = "%W%  %G%";
 
 /* Module:	Region.h
  * Purpose:	Define the structs for region drawing parameters
- * Modified:	{0} Michael VanHilst	initial version		29 June 1989
- *		{n} <who> -- <does what> -- <when>
  */
 
 struct regdrawRec {
@@ -17,8 +15,13 @@ struct regdrawRec {
   int filled_label;		/* draw-text-with-background-filled */
   int label_height;		/* minimum vertical distance between labels */
   int pad;
-} regdraw;
+  };
 
+#if defined(REGION_MAIN)
+struct regdrawRec regdraw;
+#else
+extern struct regdrawRec regdraw;
+#endif
 
 /* parameter record for regions given on a single line */
 #define REG_LIMIT 32
@@ -28,4 +31,10 @@ struct reg_param {
   char *line;
   char connector;
   char not;
-};
+  };
+
+/*
+ * Jun 29 1989	Michael VanHilst  initial version
+ *
+ * Nov 30 1998	Paul Sydney  Declare regdrawRec type separately from structure
+ */
