@@ -1,5 +1,5 @@
 /*** File libwcs/hput.c
- *** August 6, 1996
+ *** January 28, 1999
  *** By Doug Mink
 
  * Module:	hput.c (Put FITS Header parameter values)
@@ -8,28 +8,35 @@
  * Subroutine:	hputi4 (hstring,keyword,ival) sets int ival
  * Subroutine:	hputr4 (hstring,keyword,rval) sets real*4 rval
  * Subroutine:	hputr8 (hstring,keyword,dval) sets real*8 dval
- * Subroutine:	hputd8 (hstring,keyword,ndec,dval) sets real*8 dval
- * Subroutine:	hputra (hstring,keyword,lval) sets right ascnesion as string
+ * Subroutine:	hputnr8 (hstring,keyword,ndec,dval) sets real*8 dval
+ * Subroutine:	hputra (hstring,keyword,lval) sets right ascension as string
  * Subroutine:	hputdec (hstring,keyword,lval) sets declination as string
  * Subroutine:	hputl  (hstring,keyword,lval) sets logical lval
  * Subroutine:	hputs  (hstring,keyword,cval) sets character string adding ''
  * Subroutine:	hputc  (hstring,keyword,cval) sets character string cval
  * Subroutine:	hdel   (hstring,keyword) deletes entry for keyword keyword
+ * Subroutine:	hadd   (hplace,keyword) adds entry for keyword at hplace
  * Subroutine:	hchange (hstring,keyword1,keyword2) changes keyword for entry
  * Subroutine:	hputcom (hstring,keyword,comment) sets comment for parameter keyword
- * Subroutine:	ra2str (out, ra, ndec) converts RA from degrees to string
- * Subroutine:	dec2str (out, dec, ndec) converts Dec from degrees to string
+ * Subroutine:	ra2str (out, lstr, ra, ndec) converts RA from degrees to string
+ * Subroutine:	dec2str (out, lstr, dec, ndec) converts Dec from degrees to string
+ * Subroutine:	deg2str (out, lstr, deg, ndec) converts degrees to string
+ * Subroutine:	num2str (out, num, field, ndec) converts number to string
+ * Subroutine:  getltime () returns current local time as ISO-style string
+ * Subroutine:  getutime () returns current UT as ISO-style string
 
- * Copyright:   1995, 1996 Smithsonian Astrophysical Observatory
+ * Copyright:   1998 Smithsonian Astrophysical Observatory
  *              You may do anything you like with this file except remove
  *              this copyright.  The Smithsonian Astrophysical Observatory
  *              makes no representations about the suitability of this
  *              software for any purpose.  It is provided "as is" without
  *              express or implied warranty.
  */
+#include <sys/time.h>
 #include <string.h>             /* NULL, strlen, strstr, strcpy */
 #include <stdio.h>
 #include <stdlib.h>
+#include <math.h>
 #include "fitshead.h"
 
 static int verbose=0;	/* Set to 1 to print error messages and other info */
@@ -144,13 +151,18 @@ double	dval;		/* double number */
 {
     char value[30];
     char format[8];
+    int i;
 
     /* Translate value from binary to ASCII */
-    if (ndec < 0)
-	sprintf (value,"%g",dval);
+    if (ndec < 0) {
+	sprintf (format, "%%.%dg", -ndec);
+	sprintf (value, format, dval);
+	for (i = 0; i < strlen (value); i++)
+	    if (value[i] == 'e') value[i] = 'E';
+	}
     else {
-	sprintf (format,"%%.%df",ndec);
-	sprintf (value,format,dval);
+	sprintf (format, "%%.%df", ndec);
+	sprintf (value, format, dval);
 	}
 
     /* Put value into header string */
@@ -173,7 +185,7 @@ double ra;		/* Right ascension in degrees */
     char value[30];
 
     /* Translate value from binary to ASCII */
-    ra2str (value, ra, 3);
+    ra2str (value, 30, ra, 3);
 
     /* Put value into header string */
     hputs (hstring,keyword,value);
@@ -195,7 +207,7 @@ double dec;		/* Declination in degrees */
     char value[30];
 
     /* Translate value from binary to ASCII */
-    dec2str (value, dec, 2);
+    dec2str (value, 30, dec, 2);
 
     /* Put value into header string */
     hputs (hstring,keyword,value);
@@ -275,119 +287,135 @@ char *keyword;
 char *value;	/* character string containing the value for variable
 		   keyword.  trailing and leading blanks are removed.  */
 {
-	char squot = 39;
-	char line[100];
-	char newcom[50];
-	char *v, *vp, *v1, *v2, *q1, *q2, *c1, *ve;
-	char *ksearch();
-	int lkeyword, lcom, lval, lc;
+    char squot = 39;
+    char line[100];
+    char newcom[50];
+    char blank[80];
+    char *v, *vp, *v1, *v2, *q1, *q2, *c1, *ve;
+    int lkeyword, lcom, lval, lc, i, lv1;
+    char *blsearch();
 
-/*  find length of keyword and value */
-	lkeyword = strlen (keyword);
-	lval = strlen (value);
+    for (i = 0; i < 80; i++)
+	blank[i] = ' ';
 
-/*  If COMMENT or HISTORY, always add it just before the END */
-	if (lkeyword == 7 && (strncmp (keyword,"COMMENT",7) == 0 ||
-	    strncmp (keyword,"HISTORY",7) == 0)) {
+    /*  find length of keyword and value */
+    lkeyword = strlen (keyword);
+    lval = strlen (value);
+
+    /*  If COMMENT or HISTORY, always add it just before the END */
+    if (lkeyword == 7 && (strncmp (keyword,"COMMENT",7) == 0 ||
+	strncmp (keyword,"HISTORY",7) == 0)) {
 
 	/* Find end of header */
-	    v1 = ksearch (hstring,"END");
-	    v2 = v1 + 80;
+	v1 = ksearch (hstring,"END");
+	v2 = v1 + 80;
 
 	/* Move END down one line */
-	    strncpy (v2, v1, 80);
+	strncpy (v2, v1, 80);
 
 	/* Insert keyword */
-	    strncpy (v1,keyword,7);
+	strncpy (v1,keyword,7);
 
 	/* Pad with spaces */
-	    for (vp = v1+lkeyword; vp < v2; vp++)
-		*vp = ' ';
+	for (vp = v1+lkeyword; vp < v2; vp++)
+	    *vp = ' ';
+
+	if (lval > 71)
+	    lv1 = 71;
+	else
+	    lv1 = lval;
 
 	/* Insert comment */
-	    strncpy (v1+9,value,lval);
-	    return;
-	    }
+	strncpy (v1+9,value,lv1);
+	return;
+	}
 
-/* Otherwise search for keyword */
-	else
-	    v1 = ksearch (hstring,keyword);
+    /* Otherwise search for keyword */
+    else
+	v1 = ksearch (hstring,keyword);
 
-/*  Find end of header */
-	ve = ksearch (hstring,"END");
-
-/*  If parameter is not found, create a space for it */
+    /*  If parameter is not found, find a place to put it */
+    if (v1 == NULL) {
+	
+	/* First look for blank lines before END */
+        v1 = blsearch (hstring, "END");
+    
+	/*  Otherwise, create a space for it at the end of the header */
 	if (v1 == NULL) {
+	    ve = ksearch (hstring,"END");
 	    v1 = ve;
 	    v2 = v1 + 80;
 	    strncpy (v2, ve, 80);
-	    lcom = 0;
-	    newcom[0] = 0;
 	    }
-
-/*  Otherwise, extract the entry for this keyword from the header */
-	else {
-	    strncpy (line, v1, 80);
-	    line[80] = 0;
+	else
 	    v2 = v1 + 80;
+	lcom = 0;
+	newcom[0] = 0;
+	}
 
-/*  check for quoted value */
-	    q1 = strchr (line, squot);
-	    if (q1 != NULL)
-		q2 = strchr (q1+1,squot);
-	    else
-		q2 = line;
+    /*  Otherwise, extract the entry for this keyword from the header */
+    else {
+	strncpy (line, v1, 80);
+	line[80] = 0;
+	v2 = v1 + 80;
 
-/*  extract comment and remove trailing spaces */
+	/*  check for quoted value */
+	q1 = strchr (line, squot);
+	if (q1 != NULL)
+	    q2 = strchr (q1+1,squot);
+	else
+	    q2 = line;
 
-	    c1 = strchr (q2,'/');
-	    if (c1 != NULL) {
-		lcom = 80 - (c1 -line);
-		strncpy (newcom, c1+1, lcom);
-		vp = newcom + lcom - 1;
-		while (vp-- > newcom && *vp == ' ')
-		    *vp = 0;
-		lcom = strlen (newcom);
-		}
-	    else {
-		newcom[0] = 0;
-		lcom = 0;
-		}
-	    }
+	/*  extract comment and remove trailing spaces */
 
-/* Fill new entry with spaces */
-	for (vp = v1; vp < v2; vp++)
-	    *vp = ' ';
-
-/*  Copy keyword to new entry */
-	strncpy (v1, keyword, lkeyword);
-
-/*  Add parameter value in the appropriate place */
-	vp = v1 + 8;
-	*vp = '=';
-	vp = v1 + 9;
-	*vp = ' ';
-	vp = vp + 1;
-	if (*value == squot) {
-	    strncpy (vp, value, lval);
-	    if (lval+12 > 31)
-		lc = lval + 12;
-	    else
-		lc = 30;
+	c1 = strchr (q2,'/');
+	if (c1 != NULL) {
+	    lcom = 80 - (c1 - line);
+	    strncpy (newcom, c1+1, lcom);
+	    vp = newcom + lcom - 1;
+	    while (vp-- > newcom && *vp == ' ')
+		*vp = 0;
+	    lcom = strlen (newcom);
 	    }
 	else {
-	    vp = v1 + 30 - lval;
-	    strncpy (vp, value, lval);
-	    lc = 30;
+	    newcom[0] = 0;
+	    lcom = 0;
 	    }
+	}
 
-/* Add comment in the appropriate place */
+    /* Fill new entry with spaces */
+    for (vp = v1; vp < v2; vp++)
+	*vp = ' ';
+
+    /*  Copy keyword to new entry */
+    strncpy (v1, keyword, lkeyword);
+
+    /*  Add parameter value in the appropriate place */
+    vp = v1 + 8;
+    *vp = '=';
+    vp = v1 + 9;
+    *vp = ' ';
+    vp = vp + 1;
+    if (*value == squot) {
+	strncpy (vp, value, lval);
+	if (lval+12 > 31)
+	    lc = lval + 12;
+	else
+	    lc = 30;
+	}
+    else {
+	vp = v1 + 30 - lval;
+	strncpy (vp, value, lval);
+	lc = 30;
+	}
+
+    /* Add comment in the appropriate place */
 	if (lcom > 0) {
 	    if (lc+2+lcom > 80)
 		lcom = 78 - lc;
-	    vp = v1 + lc * 2;
-	    strncpy (vp, "/ ", 2);
-	    vp = vp + 2;
+	    vp = v1 + lc + 2;     /* Jul 16 1997: was vp = v1 + lc * 2 */
+	    *vp = '/';
+	    vp = vp + 1;
 	    strncpy (vp, newcom, lcom);
 	    for (v = vp + lcom; v < v2; v++)
 		*v = ' ';
@@ -442,6 +470,7 @@ hputcom (hstring,keyword,comment)
 /* search header string for variable name */
 	else {
 	    v1 = ksearch (hstring,keyword);
+	    v2 = v1 + 80;
 
 	/* if parameter is not found, return without doing anything */
 	    if (v1 == NULL) {
@@ -452,6 +481,7 @@ hputcom (hstring,keyword,comment)
 
 	/* otherwise, extract entry for this variable from the header */
 	    strncpy (line, v1, 80);
+	    line[80] = '\0'; /* Null-terminate linebefore strchr call */
 
 	/* check for quoted value */
 	    q1 = strchr (line,squot);
@@ -460,10 +490,10 @@ hputcom (hstring,keyword,comment)
 	    else
 		q2 = NULL;
 
-	    if (q2-line < 31)
-		c0 = v1 + 39;
+	    if (q2 == NULL || q2-line < 31)
+		c0 = v1 + 31;
 	    else
-		c0 = q2 + 2;
+		c0 = v1 + (q2-line) + 2; /* allan: 1997-09-30, was c0=q2+2 */
 
 	    strncpy (c0, "/ ",2);
 	    }
@@ -523,6 +553,52 @@ char *keyword;		/* Keyword of entry to be deleted */
 }
 
 
+/*  HADD - Add character string keyword = value to FITS header string
+ *	    returns 1 if entry added, else 0
+ *	    Call hputx() to put value into entry
+ */
+
+int
+hadd (hplace, keyword)
+
+char *hplace;		/* FITS header position for new keyword */
+char *keyword;		/* Keyword of entry to be deleted */
+{
+    char *v, *v1, *v2, *ve;
+    char *ksearch();
+    int i, lkey;
+
+    /*  Find end of header */
+    ve = ksearch (hplace,"END");
+
+    /*  If END is not found, return header unchanged */
+    if (ve == NULL) {
+	return (0);
+	}
+
+    v1 = hplace;
+
+    /* Shift rest of header down one line */
+    for (v = ve; v > v1; v = v - 80) {
+	v2 = v + 80;
+	strncpy (v2, v, 80);
+	}
+
+    /* Cover former first line with new keyword */
+    lkey = strlen (keyword);
+    strncpy (hplace, keyword, lkey);
+    if (lkey < 8) {
+	for (i = lkey; i < 8; i++)
+	    hplace[i] = ' ';
+	hplace[8] = '=';
+	}
+    for (i = 9; i < 80; i++)
+	hplace[i] = ' ';
+
+    return (1);
+}
+
+
 /*  HCHANGE - Changes keyword for entry from keyword1 to keyword2 in FITS
               header string
  *	      returns 1 if entry changed, else 0
@@ -562,21 +638,36 @@ char *keyword2;		/* New keyword name */
 }
 
 
-/* sprint the right ascension ra in sexagesimal format into out[] */
+/* Write the right ascension ra in sexagesimal format into string*/
 
 void
-ra2str (string, ra, ndec)
+ra2str (string, lstr, ra, ndec)
 
 char	*string;	/* Character string (returned) */
-double	ra;	/* Right ascension in degrees */
-int	ndec;	/* Number of decimal places in seconds */
+int	lstr;		/* Maximum number of characters in string */
+double	ra;		/* Right ascension in degrees */
+int	ndec;		/* Number of decimal places in seconds */
 
 {
     double a,b;
     double seconds;
+    char tstring[64];
     int hours;
     int minutes;
     int isec;
+    double dsgn;
+
+    /* Keep RA between 0 and 360 */
+    if (ra < 0.0 ) {
+	ra = -ra;
+	dsgn = -1.0;
+	}
+    else
+	dsgn = 1.0;
+    ra = fmod(ra, 360.0);
+    ra *= dsgn;
+    if (ra < 0.0)
+	ra = ra + 360.0;
 
     a = ra / 15.0;
 
@@ -591,7 +682,43 @@ int	ndec;	/* Number of decimal places in seconds */
     seconds = (b - (double)minutes) * 60.0;
     isec = (int)(seconds + 0.5);
 
-    if (ndec > 2) {
+    if (ndec > 5) {
+	if (seconds > 59.999999) {
+	    seconds = 0.0;
+	    minutes = minutes + 1;
+	    }
+	if (minutes > 59) {
+	    minutes = 0;
+	    hours = hours + 1;
+	    }
+	hours = hours % 24;
+	(void) sprintf (tstring,"%02d:%02d:%09.6f",hours,minutes,seconds);
+	}
+    else if (ndec > 4) {
+	if (seconds > 59.99999) {
+	    seconds = 0.0;
+	    minutes = minutes + 1;
+	    }
+	if (minutes > 59) {
+	    minutes = 0;
+	    hours = hours + 1;
+	    }
+	hours = hours % 24;
+	(void) sprintf (tstring,"%02d:%02d:%08.5f",hours,minutes,seconds);
+	}
+    else if (ndec > 3) {
+	if (seconds > 59.9999) {
+	    seconds = 0.0;
+	    minutes = minutes + 1;
+	    }
+	if (minutes > 59) {
+	    minutes = 0;
+	    hours = hours + 1;
+	    }
+	hours = hours % 24;
+	(void) sprintf (tstring,"%02d:%02d:%07.4f",hours,minutes,seconds);
+	}
+    else if (ndec > 2) {
 	if (seconds > 59.999) {
 	    seconds = 0.0;
 	    minutes = minutes + 1;
@@ -600,9 +727,8 @@ int	ndec;	/* Number of decimal places in seconds */
 	    minutes = 0;
 	    hours = hours + 1;
 	    }
-	if (hours > 23)
-	    hours = hours - 24;
-	(void) sprintf (string,"%2d:%02d:%06.3f",hours,minutes,seconds);
+	hours = hours % 24;
+	(void) sprintf (tstring,"%02d:%02d:%06.3f",hours,minutes,seconds);
 	}
     else if (ndec > 1) {
 	if (seconds > 59.99) {
@@ -613,9 +739,8 @@ int	ndec;	/* Number of decimal places in seconds */
 	    minutes = 0;
 	    hours = hours + 1;
 	    }
-	if (hours > 23)
-	    hours = hours - 24;
-	(void) sprintf (string,"%2d:%02d:%05.2f",hours,minutes,seconds);
+	hours = hours % 24;
+	(void) sprintf (tstring,"%02d:%02d:%05.2f",hours,minutes,seconds);
 	}
     else if (ndec > 0) {
 	if (seconds > 59.9) {
@@ -626,9 +751,8 @@ int	ndec;	/* Number of decimal places in seconds */
 	    minutes = 0;
 	    hours = hours + 1;
 	    }
-	if (hours > 23)
-	    hours = hours - 24;
-	(void) sprintf (string,"%2d:%02d:%04.1f",hours,minutes,seconds);
+	hours = hours % 24;
+	(void) sprintf (tstring,"%02d:%02d:%04.1f",hours,minutes,seconds);
 	}
     else if (ndec > -1) {
 	if (isec > 59) {
@@ -639,22 +763,30 @@ int	ndec;	/* Number of decimal places in seconds */
 	    minutes = 0;
 	    hours = hours + 1;
 	    }
-	if (hours > 23)
-	    hours = hours - 24;
-	(void) sprintf (string,"%2d:%02d:%04.1f",hours,minutes,seconds);
+	hours = hours % 24;
+	(void) sprintf (tstring,"%02d:%02d:%04.1f",hours,minutes,seconds);
+	}
+
+    /* Move formatted string to returned string */
+    if (strlen (tstring) < lstr-1)
+	strcpy (string, tstring);
+    else {
+	strncpy (string, tstring, lstr-1);
+	string[lstr-1] = 0;
 	}
     return;
 }
 
 
-/* sprint the variable a in sexagesimal format into string[]. */
+/* Write the variable a in sexagesimal format into string */
 
 void
-dec2str (string, dec, ndec)
+dec2str (string, lstr, dec, ndec)
 
 char	*string;	/* Character string (returned) */
-double	dec;	/* Declination in degrees */
-int	ndec;	/* Number of decimal places in arcseconds */
+int	lstr;		/* Maximum number of characters in string */
+double	dec;		/* Declination in degrees */
+int	ndec;		/* Number of decimal places in arcseconds */
 
 {
     double a,b;
@@ -663,6 +795,11 @@ int	ndec;	/* Number of decimal places in arcseconds */
     int degrees;
     int minutes;
     int isec;
+    char tstring[64];
+
+    /* Set declinations outside of +-90 to the closest limit */
+    if (dec > 90.0) dec = 90.0;
+    if (dec < -90.0) dec = -90.0;
 
     a = dec;
 
@@ -685,7 +822,40 @@ int	ndec;	/* Number of decimal places in arcseconds */
     seconds = (b - (double)minutes) * 60.0;
     isec = (int)(seconds + 0.5);
 
-    if (ndec > 2) {
+    if (ndec > 5) {
+	if (seconds > 59.999999) {
+	    seconds = 0.0;
+	    minutes = minutes + 1;
+	    }
+	if (minutes > 59) {
+	    minutes = 0;
+	    degrees = degrees + 1;
+	    }
+	(void) sprintf (tstring,"%c%02d:%02d:%09.6f",sign,degrees,minutes,seconds);
+	}
+    else if (ndec > 4) {
+	if (seconds > 59.99999) {
+	    seconds = 0.0;
+	    minutes = minutes + 1;
+	    }
+	if (minutes > 59) {
+	    minutes = 0;
+	    degrees = degrees + 1;
+	    }
+	(void) sprintf (tstring,"%c%02d:%02d:%08.5f",sign,degrees,minutes,seconds);
+	}
+    else if (ndec > 3) {
+	if (seconds > 59.9999) {
+	    seconds = 0.0;
+	    minutes = minutes + 1;
+	    }
+	if (minutes > 59) {
+	    minutes = 0;
+	    degrees = degrees + 1;
+	    }
+	(void) sprintf (tstring,"%c%02d:%02d:%07.4f",sign,degrees,minutes,seconds);
+	}
+    else if (ndec > 2) {
 	if (seconds > 59.999) {
 	    seconds = 0.0;
 	    minutes = minutes + 1;
@@ -694,7 +864,7 @@ int	ndec;	/* Number of decimal places in arcseconds */
 	    minutes = 0;
 	    degrees = degrees + 1;
 	    }
-	(void) sprintf (string,"%c%02d:%02d:%06.3f",sign,degrees,minutes,seconds);
+	(void) sprintf (tstring,"%c%02d:%02d:%06.3f",sign,degrees,minutes,seconds);
 	}
     else if (ndec > 1) {
 	if (seconds > 59.99) {
@@ -705,7 +875,7 @@ int	ndec;	/* Number of decimal places in arcseconds */
 	    minutes = 0;
 	    degrees = degrees + 1;
 	    }
-	(void) sprintf (string,"%c%02d:%02d:%05.2f",sign,degrees,minutes,seconds);
+	(void) sprintf (tstring,"%c%02d:%02d:%05.2f",sign,degrees,minutes,seconds);
 	}
     else if (ndec > 0) {
 	if (seconds > 59.9) {
@@ -716,7 +886,7 @@ int	ndec;	/* Number of decimal places in arcseconds */
 	    minutes = 0;
 	    degrees = degrees + 1;
 	    }
-	(void) sprintf (string,"%c%02d:%02d:%04.1f",sign,degrees,minutes,seconds);
+	(void) sprintf (tstring,"%c%02d:%02d:%04.1f",sign,degrees,minutes,seconds);
 	}
     else if (ndec > -1) {
 	if (isec > 59) {
@@ -727,10 +897,185 @@ int	ndec;	/* Number of decimal places in arcseconds */
 	    minutes = 0;
 	    degrees = degrees + 1;
 	    }
-	(void) sprintf (string,"%c%02d:%02d:%04.1f",sign,degrees,minutes,seconds);
+	(void) sprintf (tstring,"%c%02d:%02d:%04.1f",sign,degrees,minutes,seconds);
+	}
+
+    /* Move formatted string to returned string */
+    if (strlen (tstring) < lstr-1)
+	strcpy (string, tstring);
+    else {
+	strncpy (string, tstring, lstr-1);
+	string[lstr-1] = 0;
 	}
    return;
 }
+
+
+/* Write the angle a in decimal format into string */
+
+void
+deg2str (string, lstr, deg, ndec)
+
+char	*string;	/* Character string (returned) */
+int	lstr;		/* Maximum number of characters in string */
+double	deg;		/* Angle in degrees */
+int	ndec;		/* Number of decimal places in degree string */
+
+{
+    char degform[8];
+    int field;
+    char tstring[64];
+    double deg1;
+    double dsgn;
+
+    /* Keep angle between -180 and 360 degrees */
+    deg1 = deg;
+    if (deg1 < 0.0 ) {
+	deg1 = -deg1;
+	dsgn = -1.0;
+	}
+    else
+	dsgn = 1.0;
+    deg1 = fmod(deg1, 360.0);
+    deg1 *= dsgn;
+    if (deg1 <= -180.0)
+	deg1 = deg1 + 360.0;
+
+    /* Write angle to string, adding 4 digits to number of decimal places */
+    field = ndec + 4;
+    if (ndec > 0) {
+	sprintf (degform, "%%%d.%df", field, ndec);
+	sprintf (tstring, degform, deg1);
+	}
+    else {
+	sprintf (degform, "%%%4d", field);
+	sprintf (tstring, degform, (int)deg1);
+	}
+
+    /* Move formatted string to returned string */
+    if (strlen (tstring) < lstr-1)
+	strcpy (string, tstring);
+    else {
+	strncpy (string, tstring, lstr-1);
+	string[lstr-1] = 0;
+	}
+    return;
+}
+
+
+/* Write the variable a in decimal format into field-character string  */
+
+void
+num2str (string, num, field, ndec)
+
+char	*string;	/* Character string (returned) */
+double	num;		/* Number */
+int	field;		/* Number of characters in output field (0=any) */
+int	ndec;		/* Number of decimal places in degree string */
+
+{
+    char numform[8];
+
+    if (field > 0) {
+	if (ndec > 0) {
+	    sprintf (numform, "%%%d.%df", field, ndec);
+	    sprintf (string, numform, num);
+	    }
+	else {
+	    sprintf (numform, "%%%dd", field);
+	    sprintf (string, numform, (int)num);
+	    }
+	}
+    else {
+	if (ndec > 0) {
+	    sprintf (numform, "%%.%df", ndec);
+	    sprintf (string, numform, num);
+	    }
+	else {
+	    sprintf (string, "%d", (int)num);
+	    }
+	}
+    return;
+}
+
+
+/* Return current local time in ISO-style string */
+char *
+getltime ()
+
+/*   Return current local time as string
+ *
+ */
+{
+    time_t clock;
+    /* char *tstr, *ctime(); */
+    int i;
+    struct tm *localtime();
+    struct tm *time;
+    struct timeval tp;
+    struct timezone tzp;
+    int month, day, year, hour, minute, second;
+    char *isotime;
+
+    gettimeofday (&tp,&tzp);
+    clock = tp.tv_sec;
+
+    time = localtime (&clock);
+    /* tstr = ctime (&clock);
+    printf ("time is %s\n",tstr); */
+
+    year = time->tm_year;
+    if (year < 1000)
+	year = year + 1900;
+    month = time->tm_mon + 1;
+    day = time->tm_mday;
+    hour = time->tm_hour;
+    minute = time->tm_min;
+    second = time->tm_sec; 
+
+    isotime = (char *) calloc (1,32);
+
+    sprintf (isotime, "%04d-%02d-%02d %02d:%02d:%02d",
+		      year, month, day, hour, minute, second);
+
+    return (isotime);
+}
+
+/*   Return current UT as an ISO-format string */
+
+char *
+getutime ()
+
+{
+    int year, month, day, hour, minute, second;
+    long tsec;
+    struct timeval tp;
+    struct timezone tzp;
+    struct tm *ts;
+    char *isotime;
+
+    gettimeofday (&tp,&tzp);
+
+    tsec = tp.tv_sec;
+    ts = gmtime (&tsec);
+
+    year = ts->tm_year;
+    if (year < 1000)
+	year = year + 1900;
+    month = ts->tm_mon + 1;
+    day = ts->tm_mday;
+    hour = ts->tm_hour;
+    minute = ts->tm_min;
+    second = ts->tm_sec; 
+
+    isotime = (char *) calloc (1,32);
+
+    sprintf (isotime, "%04d-%02d-%02dT%02d:%02d:%02d",
+		      year, month, day, hour, minute, second);
+
+    return (isotime);
+}
+
 /* Dec 14 1995	Original subroutines
 
  * Feb  5 1996	Added HDEL to delete keyword entry from FITS header
@@ -739,4 +1084,30 @@ int	ndec;	/* Number of decimal places in arcseconds */
  * Jul 19 1996	Add HPUTRA and HPUTDEC
  * Jul 22 1996	Add HCHANGE to change keywords
  * Aug  5 1996	Add HPUTNR8 to save specific number of decimal places
+ * Oct 15 1996	Fix spelling
+ * Nov  1 1996	Add DEG2STR to set specific number of decimal places
+ * Nov  1 1996	Allow DEC2STR to handle upt to 6 decimal places
+ *
+ * Mar 20 1997	Fix format error in DEG2STR
+ * Jul  7 1997	Fix 2 errors in HPUTCOM found by Allan Brighton
+ * Jul 16 1997	Fix error in HPUTC found by Allan Brighton
+ * Jul 17 1997	Fix error in HPUTC found by Allan Brighton
+ * Sep 30 1997	Fix error in HPUTCOM found by Allan Brighton
+ * Dec 15 1997	Fix minor bugs after lint
+ * Dec 31 1997	Always put two hour digits in RA2STR
+ *
+ * Feb 25 1998	Add HADD to insert keywords at specific locations
+ * Mar 27 1998	If n is negative, write g format in HPUTNR8()
+ * Apr 24 1998	Add NUM2STR() for easy output formatting
+ * Apr 30 1998	Use BLSEARCH() to overwrite blank lines before END
+ * May 27 1998	Keep Dec between -90 and +90 in DEC2STR()
+ * May 28 1998	Keep RA between 0 and 360 in RA2STR()
+ * Jun  2 1998	Fix bug when filling in blank lines before END
+ * Jun 24 1998	Add string length to ra2str(), dec2str(), and deg2str()
+ * Jun 25 1998	Make string converstion subroutines more robust
+ * Aug 31 1998	Add getltime() and getutime()
+ * Sep 28 1998	Null-terminate comment in HPUTCOM (Allan Brighton)
+ * Oct  1 1998	Change clock declaration in getltime() from int (Allan Brighton)
+ *
+ * Jan 28 1999	Fix bug to avoid writing HISTORY or COMMENT past 80 characters
  */
