@@ -7,7 +7,7 @@ static char SccsId[] = "%W%  %G%";
  * Subroutine:	check_image()			returns: int
  * Xlib calls:	none
  * Unix calls:	stat()
- * Copyright:	1994 Smithsonian Astrophysical Observatory
+ * Copyright:	1994-1999 Smithsonian Astrophysical Observatory
  *		You may do anything you like with this file except remove
  *		this copyright.  The Smithsonian Astrophysical Observatory
  *		makes no representations about the suitability of this
@@ -15,6 +15,9 @@ static char SccsId[] = "%W%  %G%";
  *		express or implied warranty.
  * Modified:	{0} Eric Mandel, M VanHilst initial version    9 January 1989
  *		{1} Doug Mink  .fit and .fts are FITS, too    28 October 1994
+ *		{2} Doug Mink  ignore name after comma         9 October 1997
+ *		{3} Doug Mink  avoid using uninitialized ext 19 December 1997
+ *		{4} Doug Mink  check file type with isfits()  9 February 1999
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -22,6 +25,17 @@ static char SccsId[] = "%W%  %G%";
 #include <math.h>			/* define sqrt */
 #include <sys/types.h>
 #include <sys/stat.h>			/* define stat */
+
+#ifndef VMS
+#ifdef SYSV
+#include <string.h>
+#else
+#include <strings.h>            /* strlen, etc. for unenlightened BSD's */
+#endif
+#else
+#include <string.h>
+#endif
+
 #include "hfiles/constant.h"		/* define codes */
 #include "hfiles/image.h"
 #include "hfiles/cmdparse.h"		/* define parse status bits */
@@ -36,11 +50,19 @@ int check_image ( img, got_status )
      int got_status;
 {
   int len;
+  char *ext;
   static int check_array();
+  extern int isfits();
+
+  ext = NULL;
 
-  /* if no image type given, check name suffix or assume an array */
   if( (got_status & CMD_FTYPE) == 0 ) {
     if( img->filename != NULL ) {
+
+  /* if no image type given, check name suffix or assume an array */
+      ext = strchr (img->filename, ',');
+      if (ext != NULL)
+	*ext = 0;
       len = strlen(img->filename);
       if( strcmp(&img->filename[len - 5], ".fits") == 0 ) {
 	img->file_type = SOP_FITS;
@@ -58,25 +80,31 @@ int check_image ( img, got_status )
       } else if( strcmp(&img->filename[len - 4], ".imh") == 0 ) {
 	img->file_type = SOP_IRAF;
 #endif
+      } else if (isfits (img->filename)) {
+	img->file_type = SOP_FITS;
       } else
 	img->file_type = SOP_Array;
     } else
       /* if no name, default */
       img->file_type = SOP_Logo;
   }
+
   /* check for file existence and validity early on */
-  if( (img->file_type != SOP_Imtool) &&
+  if ((img->file_type != SOP_Imtool) &&
       (img->file_type != SOP_PROS) &&
       (img->file_type != SOP_Logo) &&
       (img->filename != NULL) ) {
     struct stat statbuf;
     if( stat(img->filename, &statbuf) <0 ) {
+      if (ext != NULL)
+	*ext = ',';
       (void)fprintf(stderr,
 		    "Error: cannot access image: %s\n", img->filename);
       perror(img->filename);
       return( -1 );
+      }
     }
-  }
+
   /* for arrays, we can make some checks and some calculations */
   if( img->file_type == SOP_Array ) {
     if( check_array(img) <0 ) {
@@ -97,6 +125,8 @@ int check_image ( img, got_status )
   if( img->file_type == SOP_FITS )
     img->byte_swap = !img->byte_swap;
 #endif
+  if (ext != NULL)
+    *ext = ',';
   return( 0 );
 }
 
