@@ -7,7 +7,7 @@ static char SccsId[] = "%W%  %G%";
  * Subroutine:	new_display()			returns: void
  * Subroutine:	new_panimage()			returns: void
  * Subroutine:	show_filename()			returns: void
- * Copyright:	1989 Smithsonian Astrophysical Observatory
+ * Copyright:	1989,1990,1991,1997,1998 Smithsonian Astrophysical Observatory
  *		You may do anything you like with this file except remove
  *		this copyright.  The Smithsonian Astrophysical Observatory
  *		makes no representations about the suitability of this
@@ -19,6 +19,9 @@ static char SccsId[] = "%W%  %G%";
  *		{3} MVH support for file buffer coord sys	19 Feb 1990
  *		{4} MVH altered inconsistancy in load_mainbuf	 1 Jan 1991
  *		{5} MVH changed call to copy_buf_replicate	19 Jun 1991
+ *		{6} Doug Mink added image number to title+log   14 Feb 1997
+ *		{7} Declared undeclared nim_string               1 Jun 1998
+ *		{8} Doug Mink added region title with image     14 Oct 1998
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -100,11 +103,19 @@ static void load_mainbuf ( clear )
 
   /*  Select appropriate buffer contents in image field and file coords  */
   set_buftran(&coord);
+
   /*  Set file data buffer transform  */
   set_fbuftran(&img, &coord.buf, &coord.fbuf, &coord.buftofbuf);
+
   /*  Announce the loading  */
-  if( control.verbose )
-    (void)printf("Loading new image data into main buffer, please wait.\n");
+  if( control.verbose ) {
+    if (img.filenimg > 1)
+      (void)printf("Loading new image [%d] into main buffer, please wait.\n",
+		   img.nimage);
+    else
+      (void)printf("Loading new image data into main buffer, please wait.\n");
+    }
+
   /*  Clear the buffer  */
   if( clear ) {
     bzero((char *)buffer.shortbuf, buffer.shortbuf_sz * sizeof(short));
@@ -112,15 +123,18 @@ static void load_mainbuf ( clear )
     bzero((char *)buffer.filebuf, buffer.filebuf_sz);
 */
   }
+
   /*  Load the image  */
   load_image(&coord.fb, &coord.buf, &coord.buftofile, buffer.shortbuf,
 	     buffer.filebuf, buffer.shortbuf_square, buffer.shortbuf_double);
   coord.buferror = 0;
+
   /*  Set the summed value compensation flag  */
   if( (img.block_type == SOP_ZoomSum) && ((zoom = coord.fb.block) > 1) )
     buffer.shortbuf_summing = zoom * zoom;
   else
     buffer.shortbuf_summing = 1;
+
   /*  Free data buffer if we don't need to keep it  */
   if( (!img.buffix) && ((char *)buffer.shortbuf != buffer.filebuf) ) {
     free( buffer.filebuf );
@@ -213,14 +227,17 @@ void new_panimage ()
  */
 void show_filename ( )
 {
-  int len, dir_len, file_len;
-  int dir_x, dir_y, file_y;
+  int len, dir_len, file_len, reg_len;
+  int dir_x, dir_y, file_y, reg_y;
   char *dir_end;
   char dir_string[SZ_FNAME];
   char file_string[SZ_FNAME];
+  char nim_string[SZ_FNAME];
   static XFontStruct *fontstruct = NULL;
   GC gc, set_edit_gc();
   XFontStruct *get_fontstruct();
+  char *get_region_title();
+  char *reg_string;
 
   if( fontstruct == NULL )
     fontstruct = get_fontstruct(1);
@@ -267,16 +284,28 @@ void show_filename ( )
       (void)strcat(file_string, dir_end+1);
     }
 
+    /* Add image number for multiple-image file */
+    if (img.filenimg > 1) {
+      sprintf (nim_string,"[%d]",img.nimage);
+      strcat (file_string, nim_string);
+      }
+
     dir_len  = strlen(dir_string);
     file_len = strlen(file_string);
 #endif
    }
 
-    gc = set_edit_gc(fontstruct->fid, color.gcset.menu.foreground,
-		     color.gcset.menu.background);
-    XDrawImageString(desktop.display, desktop.ID, gc,
-		     dir_x, file_y, file_string, file_len);
-    XDrawImageString(desktop.display, desktop.ID, gc,
-		     dir_x, dir_y, dir_string, dir_len);
+    gc = set_edit_gc (fontstruct->fid, color.gcset.menu.foreground,
+		      color.gcset.menu.background);
+    XDrawImageString (desktop.display, desktop.ID, gc,
+		      dir_x, file_y, file_string, file_len);
+    XDrawImageString (desktop.display, desktop.ID, gc,
+		      dir_x, dir_y, dir_string, dir_len);
+    if ((reg_string = get_region_title ()) != NULL) {
+      reg_y = dir_y + fontstruct->ascent + fontstruct->descent;
+      reg_len = strlen (reg_string);
+      XDrawImageString (desktop.display, desktop.ID, gc,
+		        dir_x, reg_y, reg_string, reg_len);
+     }
   }
 }
