@@ -8,32 +8,13 @@ static char SccsId[] = "%W%  %G%";
  * Subroutine:	crash_on_error()
  * Xlib calls:	XSetErrorHandler(), XCloseDisplay(), XGetErrorText()
  * UNIX calls:	setrlimit(), ieee_handler(), abrupt_underflow_()
- * Copyright:	1989,1990,1993-1996 Smithsonian Astrophysical Observatory
+ * Copyright:	1989-1999 Smithsonian Astrophysical Observatory
  *		You may do anything you like with this file except remove
  *		this copyright.  The Smithsonian Astrophysical Observatory
  *		makes no representations about the suitability of this
  *		software for any purpose.  It is provided "as is" without
  *		express or implied warranty.
- * Modified:	{0} Michael VanHilst	initial version		   9 May 1989
- *              {1} MVH BSDonly strings.h compatability           19 Feb 1990
- *              {2} Doug Mink	version 1.08: autoscale           10 Nov 1993
- *              {3} Doug Mink	version 1.09: Add WCS tracking    19 Oct 1994
- *              {4} Doug Mink	version 1.10: Add CD to WCS       22 Dec 1994
- *              {5} Doug Mink	version 1.11: Handle narrow files 20 Jan 1995
- *              {6} Doug Mink	version 1.12: Add DSS plate sol.   1 Mar 1995
- *              {7} Doug Mink	version 1.13: Fix bugs from STScI  5 May 1995
- *              {7} Doug Mink	version 1.13: Fix DSS plate sol.   5 May 1995
- *              {8} Doug Mink	version 1.14: Add coordinate conv.16 Aug 1995
- *              {9} Doug Mink	version 1.15: Bug fixes           18 Oct 1995
- *             {10} Doug Mink	version 1.16: DSS WCS Bug fix      7 Nov 1995
- *             {11} Doug Mink	version 1.17: IRAF .imh WCS       14 Dec 1995
- *             {11} Doug Mink	version 1.17: SECPIX WCS          22 Dec 1995
- *             {11} Doug Mink	version 1.17: Initial zoom factor  2 Jan 1996
- *             {11} Doug Mink	version 1.17: Fix pixel tracking   2 Feb 1996
- *             {12} Doug Mink	version 1.18: Fix IRAF header      9 Feb 1996
- *             {13} Doug Mink	version 1.18: Fix various bugs    26 Feb 1996
- *             {14} Doug Mink	version 1.19: Improved WCS         4 Sep 1996
- *		{n} <who> -- <does what> -- <when>
+ * Modified:	{see end of file}
  */
 
 #include <stdio.h>		/* stderr, FILE, NULL, etc. */
@@ -66,7 +47,7 @@ static char SccsId[] = "%W%  %G%";
 #endif
 #endif
 
-char *RevMsg = "release 1.19 4 September 1996";
+char *RevMsg = "SAOimage 1.26b 7 April 1999";
 int init_done = 0;
 
 /* declare and initialize parameter structs */
@@ -87,8 +68,7 @@ struct WorldCoor *wcs;		/* WCS data structure */
 struct bufferRec buffer;
 struct coordRec coord;
 Display *display;		/* display connection */
-char wcscoor[16];		/* Output coordinate system */
-char wcscommand[64];		/* WCS command */
+
 
 /*
  * Program:	main
@@ -125,11 +105,12 @@ main(argc, argv)
 #endif
 #endif
 #endif
+
   /* set up, read, and check parameters */
   init_params(argc, argv);
   if( control.verbose ) {
     (void)printf("\n Smithsonian Astrophysical Observatory image utility\n");
-    (void)printf(" SAOimage %s\n\n", RevMsg);
+    (void)printf(" %s\n\n", RevMsg);
   }
   init_packages(argc, argv);
   /* CALL MAIN EVENT LOOP (uses extern.h) */
@@ -171,10 +152,8 @@ static void init_params ( argc, argv )
   void say_goodbye(), init_connections();
 
   name = NULL;
-  wcs = NULL;
-  /* get parameters from the command line (uses extern.h) */
-  strcpy (wcscoor,"same");        /* Output coordinate system */
-  strcpy (wcscommand,"rgsc_%s");      /* WCS command */
+  img.fsmin = 0;
+  img.fsmax = 0;
 
   if( (parse_stat = parse_cmdline(argc, argv, &name)) < 0 )
     say_goodbye(1);
@@ -203,6 +182,7 @@ static void init_packages ( argc, argv )
   void init_software_cursors(), init_buttonmenu(), init_buttonbox_settings();
   void init_magnifier(), set_magnifier(), redraw_magnifier(), init_colorbox();
   void say_goodbye(), mount_buttonmenu(), new_panimage(), init_cgraph_text();
+  void move_pointer();
 
   /* get the image dimensions (need file name, type), exit if failure */
   if( init_image() == 0 ) {
@@ -296,3 +276,64 @@ static void init_server ( displayname, desktop, color )
   color->screen = dt_screen;
   display = dt_display;
 }
+/* May  9 1989	Michael VanHilst initial version
+ *
+ * Feb 19 1990	MVH BSDonly strings.h compatability
+ *
+ * Nov 10 1993	Doug Mink version 1.08: autoscale
+ *
+ * Oct 19 1994	DJM version 1.09: Add WCS tracking
+ * Dec 22 1994	DJM version 1.10: Add CD to WCS
+ *
+ * Jan 20 1995	DJM version 1.11: Handle narrow files
+ * Mar  1 1995	DJM version 1.12: Add DSS plate sol.
+ * May  5 1995	DJM version 1.13: Fix bugs from STScI
+ * May  5 1995	DJM version 1.13: Fix DSS plate sol.
+ * Aug 16 1995	DJM version 1.14: Add coordinate conv.
+ * Oct 18 1995	DJM version 1.15: Bug fixes
+ * Nov  7 1995	DJM version 1.16: DSS WCS Bug fix
+ * Dec 14 1995	DJM version 1.17: IRAF .imh WCS
+ * Dec 22 1995	DJM version 1.17: SECPIX WCS
+ *
+ * Jan  2 1996	DJM version 1.17: Initial zoom factor
+ * Feb  2 1996	DJM version 1.17: Fix pixel tracking
+ * Feb  9 1996	DJM version 1.18: Fix IRAF header
+ * Feb 26 1996	DJM version 1.18: Fix various bugs
+ * Sep  6 1996	DJM version 1.19: Improved WCS
+ 
+ * Jan 27 1997	DJM version 1.20: Improved WCS
+ * Jun  6 1997	DJM version 1.20: Fixed scaling
+ *
+ * Jan  9 1998	DJM version 1.21: Fix precession bug
+ * Jan 14 1998	DJM version 1.21: Read IRAF 2.11 im.
+ * Jan 21 1998	DJM version 1.21: Fix WCS output set
+ * Feb 18 1998	DJM version 1.22: Add Calabretta WCS
+ * Mar 16 1998	DJM version 1.22: Add NOAO TNX WCS
+ * Apr 13 1998	DJM version 1.22: Add plate polynom.
+ * Apr 14 1998	DJM version 1.22: Add ecliptic coords
+ * Apr 17 1998	DJM version 1.22: Add new IRAF types
+ * May  4 1998	DJM version 1.22: Fix LINEAR WCS
+ * May 15 1998	DJM version 1.22: Add image system
+ * May 20 1998	DJM version 1.22: Fix WCS get bugs
+ * Jun  2 1998	DJM version 1.23: Fix hput bug
+ * Jun 25 1998	DJM version 1.23: Revised WCS subs
+ * Jul  7 1998	DJM version 1.23: Handle 3-D WCS
+ * Jul 13 1998	DJM version 1.23.1: Fix various bugs
+ * Jul 16 1998	DJM version 1.23.2: Fix quad cube prj
+ * Jul 17 1998	DJM version 1.23.3: Dropped global wcs
+ * Jul 20 1998	DJM version 1.23.4: Fixed ifdef
+ * Aug  6 1998	DJM version 1.24: Add COE projection
+ * Aug 12 1998	DJM version 1.24: Add cursor centering
+ * Aug 14 1998	DJM version 1.24: Add multiple command
+ * Sep  4 1998	DJM version 1.24: Fix WCS image rotation
+ * Sep 16 1998	DJM version 1.24.1: Add NPOL; fix WCS
+ * Sep 30 1998	DJM version 1.25: Change WCSLIB headers
+ * Oct 19 1998	DJM version 1.25: Add catalog plotting
+ * Oct 29 1998	DJM version 1.25: Add key zoom + header
+ * Nov  6 1998	DJM version 1.25: Improve key zoom
+ * Nov 12 1998	DJM version 1.25: Fix mirrored images
+ * Nov 18 1998	DJM version 1.25: Fix imh2 pixfiles
+ * Nov 23 1998	DJM version 1.25: Add help and version options
+ * Nov 30 1998	DJM version 1.25: Fix bug reading very large FITS headers
+ * Nov 30 1998	DJM version 1.25: Fix a variety of bugs found by Paul Sydney
+ */
