@@ -3,14 +3,14 @@
 /* mono button: ColorA1 */
 #define ColorA1_offo_width 37
 #define ColorA1_offo_height 14
-static unsigned char ColorA1_offo_label[] = {
+static char ColorA1_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x9a, 0xc1, 0xa1, 0x83,
   0x03, 0x66, 0x22, 0x62, 0x44, 0x04, 0x22, 0x12, 0x24, 0x24, 0x08, 0x22,
   0x12, 0x24, 0x24, 0x08, 0x22, 0x12, 0x24, 0x24, 0x08, 0x22, 0x22, 0x22,
   0x44, 0x04, 0x22, 0xc2, 0x21, 0x84, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char ColorA1_offo_mask[] = {
+static char ColorA1_offo_mask[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0xff, 0xe3, 0xf3, 0xc7, 0x07, 0xff, 0xf7, 0xf7, 0xef,
   0x0f, 0xff, 0xff, 0xff, 0xff, 0x1f, 0xff, 0x7f, 0xff, 0xfe, 0x1e, 0x77,
@@ -25,14 +25,14 @@ static ButtonLabel ColorA1_offo = {
   5, 4, 0, ColorA1_offo_breaks };
 #define ColorA1_offi_width 35
 #define ColorA1_offi_height 14
-static unsigned char ColorA1_offi_label[] = {
+static char ColorA1_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xdf, 0xf1, 0xf9, 0xf1,
   0x01, 0x33, 0x1b, 0x1b, 0x1b, 0x03, 0x33, 0x1b, 0x1b, 0x1b, 0x03, 0x33,
   0x1b, 0x1b, 0x1b, 0x03, 0x33, 0x1b, 0x1b, 0x1b, 0x03, 0x33, 0x1b, 0x1b,
   0x1b, 0x03, 0x33, 0xf3, 0x19, 0xf3, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char ColorA1_offi_mask[] = {
+static char ColorA1_offi_mask[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0xff, 0xfb, 0xff, 0xfb, 0x03, 0xff, 0xff, 0xff, 0xff,
   0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xff, 0xbf, 0xbf, 0xbf, 0x07, 0xff,
@@ -57,14 +57,14 @@ static ButtonFeel ColorA1_feel = {
 /* ovlay button: ColorA2 */
 #define ColorA2_offo_width 38
 #define ColorA2_offo_height 14
-static unsigned char ColorA2_offo_label[] = {
+static char ColorA2_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x00, 0x00,
   0x08, 0x00, 0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x38, 0x04, 0x89, 0x43,
   0x10, 0x44, 0x04, 0x49, 0x44, 0x10, 0x82, 0x88, 0x08, 0x86, 0x08, 0x82,
   0x88, 0x88, 0x85, 0x08, 0x82, 0x50, 0x48, 0x04, 0x05, 0x44, 0x50, 0x48,
   0x04, 0x05, 0x38, 0x20, 0x88, 0x0b, 0x02, 0x00, 0x00, 0x00, 0x00, 0x02,
   0x00, 0x00, 0x00, 0x40, 0x02, 0x00, 0x00, 0x00, 0x80, 0x01 };
-static unsigned char ColorA2_offo_mask[] = {
+static char ColorA2_offo_mask[] = {
   0x00, 0x00, 0x1c, 0x00, 0x00, 0x00, 0x00, 0x1c, 0x00, 0x00, 0x00, 0x00,
   0x1c, 0x00, 0x00, 0x7c, 0x8e, 0xdf, 0xe7, 0x38, 0xfe, 0x8e, 0xff, 0xef,
   0x38, 0xff, 0xdf, 0xff, 0xef, 0x3d, 0xef, 0xdf, 0xff, 0xef, 0x3d, 0xc7,
@@ -79,14 +79,14 @@ static ButtonLabel ColorA2_offo = {
   5, 5, 0, ColorA2_offo_breaks };
 #define ColorA2_offi_width 36
 #define ColorA2_offi_height 14
-static unsigned char ColorA2_offi_label[] = {
+static char ColorA2_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x00,
   0x06, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x3e, 0xc3, 0xe6, 0x31,
   0x06, 0x63, 0xc3, 0x36, 0x33, 0x06, 0x63, 0x66, 0x06, 0x63, 0x06, 0x63,
   0x66, 0xe6, 0x63, 0x03, 0x63, 0x24, 0x36, 0x43, 0x03, 0x63, 0x3c, 0x36,
   0xc3, 0x03, 0x3e, 0x18, 0xe6, 0x86, 0x01, 0x00, 0x00, 0x00, 0x80, 0x01,
   0x00, 0x00, 0x00, 0xb0, 0x01, 0x00, 0x00, 0x00, 0xe0, 0x00 };
-static unsigned char ColorA2_offi_mask[] = {
+static char ColorA2_offi_mask[] = {
   0x00, 0x00, 0x0f, 0x00, 0x00, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x00, 0x00,
   0x0f, 0x00, 0x00, 0xff, 0xe7, 0xff, 0x7b, 0x0f, 0xff, 0xe7, 0xff, 0x7f,
   0x0f, 0xff, 0xff, 0xff, 0xff, 0x0f, 0xf7, 0xff, 0xff, 0xff, 0x0f, 0xf7,
@@ -111,14 +111,14 @@ static ButtonFeel ColorA2_feel = {
 /* contbias button: ColorA3 */
 #define ColorA3_offo_width 32
 #define ColorA3_offo_height 16
-static unsigned char ColorA3_offo_label[] = {
+static char ColorA3_offo_label[] = {
   0x00, 0x80, 0x80, 0x00, 0x10, 0xc0, 0x41, 0x00, 0x38, 0xe0, 0x23, 0x00,
   0x7c, 0x90, 0x14, 0x00, 0x92, 0x80, 0x08, 0x00, 0x30, 0x80, 0x04, 0x00,
   0x20, 0x00, 0x82, 0x01, 0x60, 0x00, 0x01, 0x03, 0xc0, 0x80, 0x00, 0x06,
   0x80, 0x41, 0x00, 0x04, 0x00, 0x20, 0x01, 0x0c, 0x00, 0x10, 0x01, 0x49,
   0x00, 0x28, 0x09, 0x3e, 0x00, 0xc4, 0x07, 0x1c, 0x00, 0x82, 0x03, 0x08,
   0x00, 0x01, 0x01, 0x00 };
-static unsigned char ColorA3_offo_mask[] = {
+static char ColorA3_offo_mask[] = {
   0x38, 0xe0, 0xf3, 0x03, 0x7c, 0xf0, 0xff, 0x03, 0xfe, 0xf8, 0xff, 0x01,
   0xff, 0xfd, 0xff, 0x00, 0xff, 0xff, 0xff, 0x03, 0xff, 0xff, 0xff, 0x07,
   0xff, 0xc3, 0xdf, 0x0f, 0xf8, 0xe3, 0xcf, 0x1f, 0xf8, 0xf3, 0xc7, 0x1f,
@@ -132,14 +132,14 @@ static ButtonLabel ColorA3_offo = {
   4, 0, 0, NULL };
 #define ColorA3_offi_width 32
 #define ColorA3_offi_height 16
-static unsigned char ColorA3_offi_label[] = {
+static char ColorA3_offi_label[] = {
   0x00, 0x80, 0xc0, 0x01, 0x10, 0xc0, 0xe1, 0x00, 0x38, 0xe0, 0x73, 0x00,
   0x7c, 0xf0, 0x3f, 0x00, 0xfe, 0x98, 0x1c, 0x00, 0xba, 0x81, 0x8e, 0x01,
   0x30, 0x00, 0x87, 0x03, 0x70, 0x80, 0x03, 0x07, 0xe0, 0xc0, 0x01, 0x0e,
   0xc0, 0xe1, 0x00, 0x0c, 0x80, 0x71, 0x81, 0x5d, 0x00, 0x38, 0x19, 0x7f,
   0x00, 0xfc, 0x0f, 0x3e, 0x00, 0xce, 0x07, 0x1c, 0x00, 0x87, 0x03, 0x08,
   0x80, 0x03, 0x01, 0x00 };
-static unsigned char ColorA3_offi_mask[] = {
+static char ColorA3_offi_mask[] = {
   0x38, 0xe0, 0xf3, 0x03, 0x7c, 0xf0, 0xff, 0x03, 0xfe, 0xf8, 0xff, 0x01,
   0xff, 0xfd, 0xff, 0x00, 0xff, 0xff, 0xff, 0x03, 0xff, 0xff, 0xff, 0x07,
   0xff, 0xc3, 0xdf, 0x0f, 0xf8, 0xe3, 0xcf, 0x1f, 0xf8, 0xf3, 0xc7, 0x1f,
@@ -163,14 +163,14 @@ static ButtonFeel ColorA3_feel = {
 /* thresat button: ColorA4 */
 #define ColorA4_offo_width 32
 #define ColorA4_offo_height 16
-static unsigned char ColorA4_offo_label[] = {
+static char ColorA4_offo_label[] = {
   0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0x40, 0x1c, 0x00, 0x00, 0x20, 0x3e,
   0x00, 0x00, 0x10, 0x49, 0x00, 0x00, 0x08, 0x08, 0x10, 0x00, 0x04, 0x00,
   0x38, 0x00, 0x02, 0x08, 0x7c, 0x00, 0x01, 0x49, 0x92, 0x80, 0x00, 0x3e,
   0x10, 0x40, 0x00, 0x1c, 0x00, 0x20, 0x00, 0x08, 0x10, 0x10, 0x00, 0x00,
   0x92, 0x08, 0x00, 0x00, 0x7c, 0x04, 0x00, 0x00, 0x38, 0x02, 0x00, 0x00,
   0x10, 0x00, 0x00, 0x00 };
-static unsigned char ColorA4_offo_mask[] = {
+static char ColorA4_offo_mask[] = {
   0x00, 0x00, 0xf0, 0x3f, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0xfc, 0xff,
   0x38, 0x00, 0xfe, 0xff, 0x7c, 0x00, 0xff, 0xff, 0xfe, 0x80, 0xff, 0xff,
   0xff, 0xc1, 0xdf, 0xff, 0xff, 0xe3, 0xcf, 0xff, 0xff, 0xf3, 0xc7, 0xff,
@@ -184,14 +184,14 @@ static ButtonLabel ColorA4_offo = {
   4, 0, 0, NULL };
 #define ColorA4_offi_width 32
 #define ColorA4_offi_height 16
-static unsigned char ColorA4_offi_label[] = {
+static char ColorA4_offi_label[] = {
   0x00, 0x00, 0x00, 0x08, 0x00, 0x00, 0xe0, 0x1c, 0x00, 0x00, 0x70, 0x3e,
   0x00, 0x00, 0x38, 0x7f, 0x10, 0x00, 0x9c, 0xc9, 0x38, 0x00, 0x0e, 0x08,
   0x7c, 0x00, 0x07, 0x08, 0xfe, 0x80, 0x83, 0xc9, 0x93, 0xc1, 0x01, 0x7f,
   0x10, 0xe0, 0x00, 0x3e, 0x10, 0x70, 0x00, 0x1c, 0x93, 0x39, 0x00, 0x08,
   0xfe, 0x1c, 0x00, 0x00, 0x7c, 0x0e, 0x00, 0x00, 0x38, 0x07, 0x00, 0x00,
   0x10, 0x00, 0x00, 0x00 };
-static unsigned char ColorA4_offi_mask[] = {
+static char ColorA4_offi_mask[] = {
   0x00, 0x00, 0xf0, 0x3f, 0x00, 0x00, 0xf8, 0x7f, 0x00, 0x00, 0xfc, 0xff,
   0x38, 0x00, 0xfe, 0xff, 0x7c, 0x00, 0xff, 0xff, 0xfe, 0x80, 0xff, 0xff,
   0xff, 0xc1, 0xdf, 0xff, 0xff, 0xe3, 0xcf, 0xff, 0xff, 0xf3, 0xc7, 0xff,
@@ -215,7 +215,7 @@ static ButtonFeel ColorA4_feel = {
 /* gamma button: ColorA5 */
 #define ColorA5_offo_width 46
 #define ColorA5_offo_height 14
-static unsigned char ColorA5_offo_label[] = {
+static char ColorA5_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x58, 0x1c, 0x9a, 0xd1, 0x0c, 0x07, 0x64, 0x22, 0x66, 0x32, 0x93, 0x08,
@@ -223,7 +223,7 @@ static unsigned char ColorA5_offo_label[] = {
   0x42, 0x22, 0x22, 0x12, 0x91, 0x08, 0x64, 0x22, 0x22, 0x12, 0x91, 0x08,
   0x58, 0x5c, 0x22, 0x12, 0x11, 0x17, 0x40, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x42, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char ColorA5_offo_mask[] = {
+static char ColorA5_offo_mask[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0x3e, 0xff, 0xfb, 0x9f, 0x0f,
   0xfe, 0x7f, 0xff, 0xff, 0xff, 0x1f, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x1f,
@@ -239,7 +239,7 @@ static ButtonLabel ColorA5_offo = {
   6, 5, 0, ColorA5_offo_breaks };
 #define ColorA5_offi_width 46
 #define ColorA5_offi_height 14
-static unsigned char ColorA5_offi_label[] = {
+static char ColorA5_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x7e, 0x1e, 0xdf, 0xf9, 0x8e, 0x07, 0x63, 0x33, 0x33, 0x9b, 0xd9, 0x0c,
@@ -247,7 +247,7 @@ static unsigned char ColorA5_offi_label[] = {
   0x63, 0x33, 0x33, 0x9b, 0xd9, 0x0c, 0x63, 0x33, 0x33, 0x9b, 0xd9, 0x0c,
   0x7e, 0x6e, 0x33, 0x9b, 0x99, 0x1b, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x63, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3e, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char ColorA5_offi_mask[] = {
+static char ColorA5_offi_mask[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xff, 0xbf, 0xff, 0xff, 0xdf, 0x0f,
   0xff, 0xff, 0xff, 0xff, 0xff, 0x1f, 0xff, 0xff, 0xff, 0xff, 0xff, 0x1f,
@@ -273,14 +273,14 @@ static ButtonFeel ColorA5_feel = {
 /* invert button: ColorA6 */
 #define ColorA6_offo_width 40
 #define ColorA6_offo_height 14
-static unsigned char ColorA6_offo_label[] = {
+static char ColorA6_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x00, 0x00, 0x02, 0x00,
   0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x10, 0xd2, 0x11, 0x84, 0xa1,
   0x79, 0x32, 0x12, 0x44, 0x62, 0x10, 0x12, 0x22, 0x22, 0x24, 0x10, 0x12,
   0x22, 0xe2, 0x27, 0x10, 0x12, 0x42, 0x21, 0x20, 0x10, 0x12, 0x42, 0x41,
   0x24, 0x10, 0x12, 0x82, 0x80, 0x23, 0x60, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char ColorA6_offo_mask[] = {
+static char ColorA6_offo_mask[] = {
   0x07, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x38, 0x07, 0x00,
   0x00, 0x00, 0x38, 0xff, 0x3b, 0xce, 0xf3, 0xff, 0xff, 0x3f, 0xee, 0xf7,
   0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f, 0x7f, 0xff, 0xff, 0x38, 0x3f,
@@ -295,14 +295,14 @@ static ButtonLabel ColorA6_offo = {
   5, 6, 0, ColorA6_offo_breaks };
 #define ColorA6_offi_width 40
 #define ColorA6_offi_height 14
-static unsigned char ColorA6_offi_label[] = {
+static char ColorA6_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00,
   0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x00, 0x18, 0xfb, 0x19, 0xe6, 0xf3,
   0x7d, 0x1b, 0x1b, 0x36, 0xb6, 0x19, 0x1b, 0x33, 0x33, 0x36, 0x18, 0x1b,
   0x33, 0xf3, 0x37, 0x18, 0x1b, 0x23, 0x31, 0x30, 0x18, 0x1b, 0xe3, 0x31,
   0x36, 0x18, 0x1b, 0xc3, 0xe0, 0x33, 0x70, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char ColorA6_offi_mask[] = {
+static char ColorA6_offi_mask[] = {
   0x07, 0x00, 0x00, 0x00, 0x00, 0x07, 0x00, 0x00, 0x00, 0x3c, 0x07, 0x00,
   0x00, 0x00, 0x3c, 0xff, 0x3f, 0xff, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xbf, 0xff, 0xff, 0xff, 0x3f, 0xbf,
@@ -327,14 +327,14 @@ static ButtonFeel ColorA6_feel = {
 /* cmap button: ColorA7 */
 #define ColorA7_offo_width 35
 #define ColorA7_offo_height 14
-static unsigned char ColorA7_offo_label[] = {
+static char ColorA7_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x38, 0x9a, 0xe1, 0xd0,
   0x00, 0x44, 0x66, 0x12, 0x31, 0x01, 0x02, 0x22, 0x82, 0x11, 0x02, 0x02,
   0x22, 0x62, 0x11, 0x02, 0x02, 0x22, 0x12, 0x11, 0x02, 0x44, 0x22, 0x12,
   0x31, 0x01, 0x38, 0x22, 0xe2, 0xd2, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00,
   0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00 };
-static unsigned char ColorA7_offo_mask[] = {
+static char ColorA7_offo_mask[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x7c, 0xff, 0xf3, 0xf9, 0x01, 0xfe, 0xff, 0xff, 0xfb,
   0x03, 0xff, 0xff, 0xff, 0xfb, 0x07, 0xef, 0xff, 0xff, 0xfb, 0x07, 0x07,
@@ -349,14 +349,14 @@ static ButtonLabel ColorA7_offo = {
   5, 4, 0, ColorA7_offo_breaks };
 #define ColorA7_offi_width 35
 #define ColorA7_offi_height 14
-static unsigned char ColorA7_offi_label[] = {
+static char ColorA7_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x3e, 0xdf, 0xf1, 0xf8,
   0x01, 0x63, 0x33, 0x9b, 0x19, 0x03, 0x03, 0x33, 0x83, 0x19, 0x03, 0x03,
   0x33, 0xf3, 0x19, 0x03, 0x63, 0x33, 0x9b, 0x19, 0x03, 0x63, 0x33, 0x9b,
   0x19, 0x03, 0x3e, 0x33, 0x73, 0xfb, 0x01, 0x00, 0x00, 0x00, 0x18, 0x00,
   0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00 };
-static unsigned char ColorA7_offi_mask[] = {
+static char ColorA7_offi_mask[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0xff, 0xff, 0xfb, 0xfd, 0x03, 0xff, 0xff, 0xff, 0xff,
   0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xf7, 0xff, 0xff, 0xbf, 0x07, 0xf7,
