@@ -3,13 +3,13 @@
 /* view button: RegionA1 */
 #define RegionA1_offo_width 31
 #define RegionA1_offo_height 14
-static unsigned char RegionA1_offo_label[] = {
+static char RegionA1_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x82, 0x84, 0x21, 0x22, 0x82, 0x44, 0x22, 0x22,
   0x44, 0x24, 0x44, 0x15, 0x44, 0xe4, 0x47, 0x15, 0x28, 0x24, 0x40, 0x15,
   0x28, 0x44, 0x84, 0x08, 0x10, 0x84, 0x83, 0x08, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA1_offo_mask[] = {
+static char RegionA1_offo_mask[] = {
   0x00, 0x0e, 0x00, 0x00, 0x00, 0x0e, 0x00, 0x00, 0x00, 0x0e, 0x00, 0x00,
   0xc7, 0xcf, 0x73, 0x77, 0xc7, 0xef, 0x77, 0x77, 0xef, 0xff, 0xff, 0x7f,
   0xef, 0xff, 0xff, 0x7f, 0xfe, 0xfe, 0xef, 0x3f, 0xfe, 0xfe, 0xef, 0x3f,
@@ -23,13 +23,13 @@ static ButtonLabel RegionA1_offo = {
   4, 4, 0, RegionA1_offo_breaks };
 #define RegionA1_offi_width 32
 #define RegionA1_offi_height 14
-static unsigned char RegionA1_offi_label[] = {
+static char RegionA1_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00, 0x00, 0x06, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0xc3, 0xe6, 0x33, 0x62, 0xc3, 0x36, 0x36, 0x62,
   0x66, 0x36, 0x66, 0x37, 0x66, 0xf6, 0x67, 0x37, 0x24, 0x36, 0xe0, 0x3d,
   0x3c, 0x36, 0xc6, 0x18, 0x18, 0xe6, 0xc3, 0x18, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA1_offi_mask[] = {
+static char RegionA1_offi_mask[] = {
   0x00, 0x0f, 0x00, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x00, 0x0f, 0x00, 0x00,
   0xe7, 0xff, 0x7f, 0xf7, 0xe7, 0xff, 0x7f, 0xf7, 0xff, 0xff, 0xff, 0xff,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xff, 0xff, 0xff, 0x7f,
@@ -53,13 +53,13 @@ static ButtonFeel RegionA1_feel = {
 /* label button: RegionA2 */
 #define RegionA2_offo_width 30
 #define RegionA2_offo_height 14
-static unsigned char RegionA2_offo_label[] = {
+static char RegionA2_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x02, 0x10, 0x00, 0x10, 0x02, 0x10, 0x00, 0x10,
   0x02, 0x10, 0x00, 0x10, 0xe2, 0xd0, 0xc0, 0x10, 0x12, 0x31, 0x21, 0x11,
   0x82, 0x11, 0x12, 0x12, 0x62, 0x11, 0xf2, 0x13, 0x12, 0x11, 0x12, 0x10,
   0x12, 0x31, 0x21, 0x12, 0xe2, 0xd2, 0xc0, 0x11, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA2_offo_mask[] = {
+static char RegionA2_offo_mask[] = {
   0x07, 0x38, 0x00, 0x38, 0x07, 0x38, 0x00, 0x38, 0x07, 0x38, 0x00, 0x38,
   0xf7, 0xf9, 0xe1, 0x39, 0xff, 0xfb, 0xf3, 0x3b, 0xff, 0xfb, 0xff, 0x3f,
   0xff, 0xfb, 0xff, 0x3f, 0xff, 0x3b, 0xff, 0x3f, 0xff, 0xfb, 0xff, 0x3f,
@@ -73,13 +73,13 @@ static ButtonLabel RegionA2_offo = {
   4, 5, 0, RegionA2_offo_breaks };
 #define RegionA2_offi_width 30
 #define RegionA2_offi_height 14
-static unsigned char RegionA2_offi_label[] = {
+static char RegionA2_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x03, 0x18, 0x00, 0x18, 0x03, 0x18, 0x00, 0x18,
   0x03, 0x18, 0x00, 0x18, 0xf3, 0xf8, 0xf1, 0x19, 0x9b, 0x19, 0x1b, 0x1b,
   0x83, 0x19, 0x1b, 0x1b, 0xf3, 0x19, 0xfb, 0x1b, 0x9b, 0x19, 0x1b, 0x18,
   0x9b, 0x19, 0x1b, 0x1b, 0x73, 0xfb, 0xf1, 0x19, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA2_offi_mask[] = {
+static char RegionA2_offi_mask[] = {
   0x07, 0x3c, 0x00, 0x3c, 0x07, 0x3c, 0x00, 0x3c, 0x07, 0x3c, 0x00, 0x3c,
   0xff, 0xfd, 0xfb, 0x3f, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0x3f,
   0xff, 0xbf, 0xff, 0x3f, 0xff, 0xbf, 0xff, 0x3f, 0xff, 0xbf, 0xff, 0x3f,
@@ -103,14 +103,14 @@ static ButtonFeel RegionA2_feel = {
 /* cycle button: RegionA3 */
 #define RegionA3_offo_width 36
 #define RegionA3_offo_height 14
-static unsigned char RegionA3_offo_label[] = {
+static char RegionA3_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00,
   0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x38, 0x82, 0x70, 0x84,
   0x01, 0x44, 0x82, 0x88, 0x44, 0x02, 0x02, 0x44, 0x04, 0x24, 0x04, 0x02,
   0x44, 0x04, 0xe4, 0x07, 0x02, 0x28, 0x04, 0x24, 0x00, 0x44, 0x28, 0x88,
   0x44, 0x04, 0x38, 0x10, 0x70, 0x84, 0x03, 0x00, 0x10, 0x00, 0x00, 0x00,
   0x00, 0x12, 0x00, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00 };
-static unsigned char RegionA3_offo_mask[] = {
+static char RegionA3_offo_mask[] = {
   0x00, 0x00, 0x00, 0x0e, 0x00, 0x00, 0x00, 0x00, 0x0e, 0x00, 0x00, 0x00,
   0x00, 0x0e, 0x00, 0x7c, 0xc7, 0xf9, 0xce, 0x03, 0xfe, 0xc7, 0xfd, 0xef,
   0x07, 0xff, 0xef, 0xff, 0xff, 0x0f, 0xef, 0xef, 0xdf, 0xff, 0x0f, 0x07,
@@ -125,14 +125,14 @@ static ButtonLabel RegionA3_offo = {
   5, 5, 0, RegionA3_offo_breaks };
 #define RegionA3_offi_width 35
 #define RegionA3_offi_height 14
-static unsigned char RegionA3_offi_label[] = {
+static char RegionA3_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x00,
   0x00, 0x03, 0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x3e, 0x63, 0x3e, 0xf3,
   0x01, 0x63, 0x63, 0x63, 0x1b, 0x03, 0x03, 0x66, 0x03, 0x1b, 0x03, 0x03,
   0x36, 0x03, 0xfb, 0x03, 0x63, 0x34, 0x63, 0x1b, 0x00, 0x63, 0x3c, 0x63,
   0x1b, 0x03, 0x3e, 0x18, 0x3e, 0xf3, 0x01, 0x00, 0x18, 0x00, 0x00, 0x00,
   0x00, 0x1b, 0x00, 0x00, 0x00, 0x00, 0x0e, 0x00, 0x00, 0x00 };
-static unsigned char RegionA3_offi_mask[] = {
+static char RegionA3_offi_mask[] = {
   0x00, 0x00, 0x80, 0x07, 0x00, 0x00, 0x00, 0x80, 0x07, 0x00, 0x00, 0x00,
   0x80, 0x07, 0x00, 0xff, 0xf7, 0xff, 0xff, 0x03, 0xff, 0xf7, 0xff, 0xff,
   0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xf7, 0xff, 0xf7, 0xff, 0x07, 0xf7,
@@ -157,13 +157,13 @@ static ButtonFeel RegionA3_feel = {
 /* omit button: RegionA4 */
 #define RegionA4_offo_width 29
 #define RegionA4_offo_height 14
-static unsigned char RegionA4_offo_label[] = {
+static char RegionA4_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x20, 0x02,
   0x00, 0x00, 0x00, 0x02, 0x38, 0x34, 0x23, 0x0f, 0x44, 0xcc, 0x24, 0x02,
   0x82, 0x44, 0x24, 0x02, 0x82, 0x44, 0x24, 0x02, 0x82, 0x44, 0x24, 0x02,
   0x44, 0x44, 0x24, 0x02, 0x38, 0x44, 0x24, 0x0c, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA4_offo_mask[] = {
+static char RegionA4_offo_mask[] = {
   0x00, 0x00, 0x70, 0x00, 0x00, 0x00, 0x70, 0x07, 0x00, 0x00, 0x70, 0x07,
   0x7c, 0xfe, 0xf7, 0x1f, 0xfe, 0xfe, 0xff, 0x1f, 0xff, 0xff, 0xff, 0x1f,
   0xef, 0xff, 0x7f, 0x07, 0xc7, 0xef, 0x7e, 0x07, 0xef, 0xef, 0x7e, 0x07,
@@ -177,13 +177,13 @@ static ButtonLabel RegionA4_offo = {
   4, 4, 0, RegionA4_offo_breaks };
 #define RegionA4_offi_width 28
 #define RegionA4_offi_height 14
-static unsigned char RegionA4_offi_label[] = {
+static char RegionA4_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x98, 0x01,
   0x00, 0x00, 0x80, 0x01, 0x3e, 0xdf, 0xd9, 0x07, 0x63, 0x33, 0x9b, 0x01,
   0x63, 0x33, 0x9b, 0x01, 0x63, 0x33, 0x9b, 0x01, 0x63, 0x33, 0x9b, 0x01,
   0x63, 0x33, 0x9b, 0x01, 0x3e, 0x33, 0x1b, 0x07, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA4_offi_mask[] = {
+static char RegionA4_offi_mask[] = {
   0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0xfc, 0x03, 0x00, 0x00, 0xfc, 0x03,
   0xff, 0xff, 0xff, 0x0f, 0xff, 0xff, 0xff, 0x0f, 0xff, 0xff, 0xff, 0x0f,
   0xf7, 0xff, 0xff, 0x03, 0xf7, 0xff, 0xff, 0x03, 0xf7, 0xff, 0xff, 0x03,
@@ -207,14 +207,14 @@ static ButtonFeel RegionA4_feel = {
 /* reset button: RegionA5 */
 #define RegionA5_offo_width 36
 #define RegionA5_offo_height 14
-static unsigned char RegionA5_offo_label[] = {
+static char RegionA5_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x01, 0x00, 0x00, 0x00, 0x00, 0x01, 0x1a, 0x06, 0x0f, 0x86,
   0x07, 0x06, 0x89, 0x10, 0x09, 0x01, 0x82, 0x90, 0x80, 0x10, 0x01, 0x82,
   0x1f, 0x8f, 0x1f, 0x01, 0x82, 0x00, 0x90, 0x00, 0x01, 0x02, 0x91, 0x10,
   0x11, 0x01, 0x02, 0x0e, 0x0f, 0x0e, 0x06, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA5_offo_mask[] = {
+static char RegionA5_offo_mask[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x03, 0x00, 0x00,
   0x00, 0x80, 0x03, 0x3f, 0x8f, 0x1f, 0xcf, 0x0f, 0xbf, 0xdf, 0xbf, 0xdf,
   0x0f, 0xff, 0xff, 0xff, 0xff, 0x0f, 0xcf, 0xff, 0xff, 0xbf, 0x03, 0xc7,
@@ -229,14 +229,14 @@ static ButtonLabel RegionA5_offo = {
   5, 5, 0, RegionA5_offo_breaks };
 #define RegionA5_offi_width 35
 #define RegionA5_offi_height 14
-static unsigned char RegionA5_offi_label[] = {
+static char RegionA5_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0xc0, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x9f, 0x8f, 0xc7, 0xe7,
   0x03, 0xdb, 0xd8, 0x6c, 0xcc, 0x00, 0xc3, 0xd8, 0x61, 0xcc, 0x00, 0xc3,
   0x9f, 0xe7, 0xcf, 0x00, 0xc3, 0x00, 0x6e, 0xc0, 0x00, 0xc3, 0xd8, 0x6c,
   0xcc, 0x00, 0x83, 0x8f, 0xc7, 0x87, 0x03, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA5_offi_mask[] = {
+static char RegionA5_offi_mask[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x01, 0x00, 0x00,
   0x00, 0xe0, 0x01, 0xff, 0xdf, 0xef, 0xff, 0x07, 0xff, 0xff, 0xff, 0xff,
   0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xff, 0xff, 0xff, 0xff, 0x01, 0xe7,
@@ -261,14 +261,14 @@ static ButtonFeel RegionA5_feel = {
 /* write button: RegionA6 */
 #define RegionA6_offo_width 34
 #define RegionA6_offo_height 14
-static unsigned char RegionA6_offo_label[] = {
+static char RegionA6_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00,
   0x44, 0x00, 0x00, 0x00, 0x00, 0x40, 0x00, 0x00, 0x22, 0xd2, 0xe4, 0x61,
   0x00, 0x22, 0x32, 0x44, 0x90, 0x00, 0x54, 0x11, 0x44, 0x08, 0x01, 0x54,
   0x11, 0x44, 0xf8, 0x01, 0x54, 0x11, 0x44, 0x08, 0x00, 0x88, 0x10, 0x44,
   0x10, 0x01, 0x88, 0x10, 0x84, 0xe1, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA6_offo_mask[] = {
+static char RegionA6_offo_mask[] = {
   0x00, 0x00, 0x0e, 0x00, 0x00, 0x00, 0x00, 0xee, 0x00, 0x00, 0x00, 0x00,
   0xee, 0x00, 0x00, 0x77, 0xff, 0xff, 0xf3, 0x00, 0x77, 0xff, 0xff, 0xfb,
   0x01, 0xff, 0xff, 0xff, 0xff, 0x03, 0xff, 0x7f, 0xee, 0xfc, 0x03, 0xfe,
@@ -283,14 +283,14 @@ static ButtonLabel RegionA6_offo = {
   5, 5, 0, RegionA6_offo_breaks };
 #define RegionA6_offi_width 35
 #define RegionA6_offi_height 14
-static unsigned char RegionA6_offi_label[] = {
+static char RegionA6_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0x00, 0x00, 0x00, 0x00,
   0xcc, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00, 0x23, 0xf6, 0xed, 0xf3,
   0x01, 0x23, 0xb6, 0xcd, 0x18, 0x03, 0x76, 0x33, 0xcc, 0x18, 0x03, 0x76,
   0x33, 0xcc, 0xf8, 0x03, 0xde, 0x33, 0xcc, 0x18, 0x00, 0x8c, 0x31, 0xcc,
   0x18, 0x03, 0x8c, 0x31, 0x8c, 0xf3, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA6_offi_mask[] = {
+static char RegionA6_offi_mask[] = {
   0x00, 0x00, 0x1e, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x01, 0x00, 0x00, 0x00,
   0xfe, 0x01, 0x00, 0x77, 0xff, 0xff, 0xff, 0x03, 0x77, 0xff, 0xff, 0xff,
   0x07, 0xff, 0xff, 0xff, 0xff, 0x07, 0xff, 0xff, 0xff, 0xfd, 0x07, 0xff,
@@ -315,13 +315,13 @@ static ButtonFeel RegionA6_feel = {
 /* read button: RegionA7 */
 #define RegionA7_offo_width 30
 #define RegionA7_offo_height 14
-static unsigned char RegionA7_offo_label[] = {
+static char RegionA7_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
   0x00, 0x00, 0x00, 0x10, 0x1a, 0x06, 0x07, 0x16, 0x06, 0x89, 0x08, 0x19,
   0x82, 0x10, 0x8c, 0x10, 0x82, 0x1f, 0x8b, 0x10, 0x82, 0x80, 0x88, 0x10,
   0x02, 0x91, 0x08, 0x19, 0x02, 0x0e, 0x17, 0x16, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA7_offo_mask[] = {
+static char RegionA7_offo_mask[] = {
   0x00, 0x00, 0x00, 0x38, 0x00, 0x00, 0x00, 0x38, 0x00, 0x00, 0x00, 0x38,
   0x3f, 0x8f, 0x0f, 0x3f, 0xbf, 0xdf, 0x9f, 0x3f, 0xff, 0xff, 0xdf, 0x3f,
   0xcf, 0xff, 0xdf, 0x3f, 0xc7, 0xff, 0xdf, 0x39, 0xc7, 0xff, 0xdf, 0x3f,
@@ -335,13 +335,13 @@ static ButtonLabel RegionA7_offo = {
   4, 4, 0, RegionA7_offo_breaks };
 #define RegionA7_offi_width 30
 #define RegionA7_offi_height 14
-static unsigned char RegionA7_offi_label[] = {
+static char RegionA7_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00, 0x18,
   0x00, 0x00, 0x00, 0x18, 0x9f, 0x8f, 0x87, 0x1f, 0xdb, 0xd8, 0xcc, 0x18,
   0xc3, 0x18, 0xcc, 0x18, 0xc3, 0x9f, 0xcf, 0x18, 0xc3, 0xc0, 0xcc, 0x18,
   0xc3, 0xd8, 0xcc, 0x18, 0x83, 0x8f, 0x9b, 0x1f, 0x00, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static unsigned char RegionA7_offi_mask[] = {
+static char RegionA7_offi_mask[] = {
   0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x3c,
   0xff, 0xdf, 0xcf, 0x3f, 0xff, 0xff, 0xff, 0x3f, 0xff, 0xff, 0xff, 0x3f,
   0xff, 0xff, 0xff, 0x3d, 0xe7, 0xff, 0xff, 0x3d, 0xe7, 0xff, 0xff, 0x3d,
